@@ -17,7 +17,21 @@
  FOR A PARTICULAR PURPOSE.  See the license for more details.
 */
 
-#include <ql/quantlib.hpp>
+#include <ql/qldefines.hpp>
+#ifdef BOOST_MSVC
+#  include <ql/auto_link.hpp>
+#endif
+#include <ql/experimental/credit/gaussianlhplossmodel.hpp>
+#include <ql/experimental/credit/constantlosslatentmodel.hpp>
+#include <ql/experimental/credit/binomiallossmodel.hpp>
+#include <ql/experimental/credit/randomdefaultlatentmodel.hpp>
+#include <ql/experimental/credit/randomlosslatentmodel.hpp>
+#include <ql/experimental/credit/spotlosslatentmodel.hpp>
+#include <ql/experimental/credit/basecorrelationlossmodel.hpp>
+#include <ql/termstructures/credit/flathazardrate.hpp>
+#include <ql/time/daycounters/actual365fixed.hpp>
+#include <ql/time/calendars/target.hpp>
+#include <ql/currencies/europe.hpp>
 
 #include <boost/timer.hpp>
 #include <boost/make_shared.hpp>
@@ -26,6 +40,7 @@
 
 #include <iostream>
 #include <iomanip>
+#include <string>
 
 using namespace std;
 using namespace QuantLib;
@@ -108,6 +123,7 @@ int main(int, char* []) {
             std::vector<Real>(1, std::sqrt(factorValue)));
 
         // --- LHP model --------------------------
+        #ifndef QL_PATCH_SOLARIS
         boost::shared_ptr<DefaultLossModel> lmGLHP(
             boost::make_shared<GaussianLHPLossModel>(
                 fctrsWeights[0][0] * fctrsWeights[0][0], recoveries));
@@ -128,6 +144,8 @@ int main(int, char* []) {
         std::cout << "Gaussian Binomial Expected 10-Yr Losses: "  << std::endl;
         std::cout << theBskt->expectedTrancheLoss(calcDate) << std::endl;
 
+        #endif
+
         // --- T Binomial model --------------------
         TCopulaPolicy::initTraits initT;
         initT.tOrders = std::vector<Integer>(2, 3);
@@ -145,6 +163,8 @@ int main(int, char* []) {
         std::cout << theBskt->expectedTrancheLoss(calcDate) << std::endl;
 
         // --- G Inhomogeneous model ---------------
+        Size numSimulations = 100000;
+        #ifndef QL_PATCH_SOLARIS
         boost::shared_ptr<GaussianConstantLossLM> gLM(
             boost::make_shared<GaussianConstantLossLM>(fctrsWeights, 
             recoveries,
@@ -162,14 +182,13 @@ int main(int, char* []) {
 
         // --- G Random model ---------------------
         // Gaussian random joint default model:
-        Size numSimulations = 100000;
         // Size numCoresUsed = 4;
         // Sobol, many cores
         boost::shared_ptr<DefaultLossModel> rdlmG(
             boost::make_shared<RandomDefaultLM<GaussianCopulaPolicy, 
             RandomSequenceGenerator<
                 BoxMullerGaussianRng<MersenneTwisterUniformRng> > > >(gLM, 
-                    recoveries, numSimulations, 1.e-6, 2863311530));
+                    recoveries, numSimulations, 1.e-6, 2863311530UL));
         //boost::shared_ptr<DefaultLossModel> rdlmG(
         //    boost::make_shared<RandomDefaultLM<GaussianCopulaPolicy> >(gLM, 
         //        recoveries, numSimulations, 1.e-6, 2863311530));
@@ -177,6 +196,7 @@ int main(int, char* []) {
 
         std::cout << "Random G Expected 10-Yr Losses: "  << std::endl;
         std::cout << theBskt->expectedTrancheLoss(calcDate) << std::endl;
+        #endif
 
         // --- StudentT Random model ---------------------
         // Sobol, many cores
@@ -184,7 +204,7 @@ int main(int, char* []) {
             boost::make_shared<RandomDefaultLM<TCopulaPolicy, 
             RandomSequenceGenerator<
                 PolarStudentTRng<MersenneTwisterUniformRng> > > >(ktTLossLM, 
-                    recoveries, numSimulations, 1.e-6, 2863311530));
+                    recoveries, numSimulations, 1.e-6, 2863311530UL));
         //boost::shared_ptr<DefaultLossModel> rdlmT(
         //    boost::make_shared<RandomDefaultLM<TCopulaPolicy> >(ktTLossLM, 
         //        recoveries, numSimulations, 1.e-6, 2863311530));
@@ -195,6 +215,7 @@ int main(int, char* []) {
 
 
         // Spot Loss latent model: 
+        #ifndef QL_PATCH_SOLARIS
         std::vector<std::vector<Real> > fctrsWeightsRR(2 * hazardRates.size(), 
             std::vector<Real>(1, std::sqrt(factorValue)));
         Real modelA = 2.2;
@@ -212,7 +233,7 @@ int main(int, char* []) {
         // Sobol, many cores
         boost::shared_ptr<DefaultLossModel> rdLlmG(
             boost::make_shared<RandomLossLM<GaussianCopulaPolicy> >(sptLG, 
-                numSimulations, 1.e-6, 2863311530));
+                numSimulations, 1.e-6, 2863311530UL));
         theBskt->setLossModel(rdLlmG);
 
         std::cout << "Random Loss G Expected 10-Yr Losses: "  << std::endl;
@@ -223,16 +244,12 @@ int main(int, char* []) {
         // Sobol, many cores
         boost::shared_ptr<DefaultLossModel> rdLlmT(
             boost::make_shared<RandomLossLM<TCopulaPolicy> >(sptLT, 
-                numSimulations, 1.e-6, 2863311530));
+                numSimulations, 1.e-6, 2863311530UL));
         theBskt->setLossModel(rdLlmT);
 
         std::cout << "Random Loss T Expected 10-Yr Losses: "  << std::endl;
         std::cout << theBskt->expectedTrancheLoss(calcDate) << std::endl;
 
-
-
-
-
         // Base Correlation model set up to test cocherence with base LHP model
         std::vector<Period> bcTenors;
         bcTenors.push_back(Period(1, Years));
@@ -282,7 +299,7 @@ int main(int, char* []) {
         std::cout << "Base Correlation GLHP Expected 10-Yr Losses: "  
             << std::endl;
         std::cout << theBskt->expectedTrancheLoss(calcDate) << std::endl;
-
+        #endif
 
         Real seconds  = timer.elapsed();
         Integer hours = Integer(seconds/3600);
