@@ -225,10 +225,12 @@ namespace QuantLib {
             refStart = start = schedule_.date(i);
             refEnd   =   end = schedule_.date(i+1);
             paymentDate = calendar.adjust(end, paymentAdjustment_);
-            if (i == 0 && !schedule_.isRegular(i+1))
+            if (i == 0 && schedule_.hasIsRegular() && !schedule_.isRegular(i+1)
+                && schedule_.hasTenor())
                 refStart = calendar.adjust(end - schedule_.tenor(),
                                            paymentAdjustment_);
-            if (i == n-1 && !schedule_.isRegular(i+1))
+            if (i == n-1 && schedule_.hasIsRegular() && !schedule_.isRegular(i+1)
+                && schedule_.hasTenor())
                 refEnd = calendar.adjust(start + schedule_.tenor(),
                                          paymentAdjustment_);
 
