@@ -288,11 +288,11 @@ namespace QuantLib {
                                                                 exCouponEndOfMonth_);
                 }
 
-                if (i==0   && !schedule_.isRegular(i+1)) {
+                if (i==0   && schedule_.hasIsRegular() && !schedule_.isRegular(i+1)) {
                     BusinessDayConvention bdc = schedule_.businessDayConvention();
                     refStart = schedule_.calendar().adjust(end - schedule_.tenor(), bdc);
                 }
-                if (i==n-1 && !schedule_.isRegular(i+1)) {
+                if (i==n-1 && schedule_.hasIsRegular() && !schedule_.isRegular(i+1)) {
                     BusinessDayConvention bdc = schedule_.businessDayConvention();
                     refEnd = schedule_.calendar().adjust(start + schedule_.tenor(), bdc);
                 }
