@@ -156,7 +156,7 @@ namespace QuantLib {
 
             // price each period
             for (PricingPeriods::const_iterator pi = pricingPeriods_.begin();
-                 pi != pricingPeriods_.end(); pi++) {
+                 pi != pricingPeriods_.end(); ++pi) {
                 const boost::shared_ptr<PricingPeriod>& pricingPeriod = *pi;
 
                 Integer periodDayCount = 0;
@@ -237,7 +237,7 @@ namespace QuantLib {
                 for (std::map<Date, EnergyDailyPosition>::iterator dpi =
                          dailyPositions_.find(periodStartDate);
                      dpi != dailyPositions_.end() &&
-                         dpi->first <= pricingPeriod->endDate(); dpi++) {
+                         dpi->first <= pricingPeriod->endDate(); ++dpi) {
                     EnergyDailyPosition& dailyPosition = dpi->second;
                     dailyPosition.quantityAmount = avgDailyQuantityAmount;
                     dailyPosition.riskDelta =
@@ -296,7 +296,7 @@ namespace QuantLib {
 
             for (SecondaryCostAmounts::const_iterator i =
                      secondaryCostAmounts_.begin();
-                 i != secondaryCostAmounts_.end(); i++) {
+                 i != secondaryCostAmounts_.end(); ++i) {
                 Real amount = i->second.value();
                 NPV_ -= amount;
             }
