@@ -30,6 +30,22 @@ using namespace std;
 
 namespace QuantLib {
 
+    RiskyBond::RiskyBond(
+                 const std::string& name,
+                 const Currency& ccy,
+                 Real recoveryRate,
+                 const Handle<DefaultProbabilityTermStructure>& defaultTS,
+                 const Handle<YieldTermStructure>& yieldTS,
+                 Natural settlementDays, Calendar calendar)
+    : name_(name), ccy_(ccy), recoveryRate_(recoveryRate),
+      defaultTS_(defaultTS), yieldTS_(yieldTS),
+      settlementDays_(settlementDays), calendar_(calendar) {
+        registerWith (yieldTS_);
+        registerWith (defaultTS_);
+        //the two above might not be registered with evalDate
+        registerWith(Settings::instance().evaluationDate());
+    }
+
     bool RiskyBond::isExpired() const {
         return detail::simple_event(maturityDate()).hasOccurred();
     }
@@ -41,12 +57,13 @@ namespace QuantLib {
     void RiskyBond::performCalculations() const {
         NPV_ = 0;
         Date today = Settings::instance().evaluationDate();
+        Date npvDate = calendar_.advance(today, settlementDays_, Days);
         std::vector<boost::shared_ptr<CashFlow> > cf = cashflows();
         Date d1 = effectiveDate();
         for (Size i = 0; i < cf.size(); i++) {
             Date d2 = cf[i]->date();
-            if (d2 > today) {
-                d1 = max(today , d1);
+            if (d2 > npvDate) {
+                d1 = max(npvDate , d1);
                 Date defaultDate = d1 + (d2-d1)/2;
 
                 Real coupon = cf[i]->amount()
@@ -59,15 +76,17 @@ namespace QuantLib {
             }
             d1 = d2;
         }
+        valuationDate_ = npvDate;
     }
 
     Real RiskyBond::riskfreeNPV() const {
         Date today = Settings::instance().evaluationDate();
+        Date npvDate = calendar_.advance(today, settlementDays_, Days);
         Real npv = 0;
         std::vector<boost::shared_ptr<CashFlow> > cf = cashflows();
         for (Size i = 0; i < cf.size(); i++) {
             Date d2 = cf[i]->date();
-            if (d2 > today)
+            if (d2 > npvDate)
                 npv += cf[i]->amount() * yieldTS()->discount(d2);
         }
         return npv;
@@ -75,10 +94,11 @@ namespace QuantLib {
 
     Real RiskyBond::totalFutureFlows() const {
         Date today = Settings::instance().evaluationDate();
+        Date npvDate = calendar_.advance(today, settlementDays_, Days);
         Real flow = 0;
         std::vector<boost::shared_ptr<CashFlow> > cf = cashflows();
         for (Size i = 0; i < cf.size(); i++) {
-            if (cf[i]->date() > today)
+            if (cf[i]->date() > npvDate)
                 flow += cf[i]->amount();
         }
         return flow;
@@ -88,11 +108,12 @@ namespace QuantLib {
         std::vector<boost::shared_ptr<CashFlow> > expected;
         std::vector<boost::shared_ptr<CashFlow> > cf = cashflows();
         Date today = Settings::instance().evaluationDate();
+        Date npvDate = calendar_.advance(today, settlementDays_, Days);
         Date d1 = effectiveDate();
         for (Size i = 0; i < cf.size(); i++) {
             Date d2 = cf[i]->date();
-            if (d2 > today) {
-                d1 = max(today , d1);
+            if (d2 > npvDate) {
+                d1 = max(npvDate, d1);
                 Date defaultDate = d1 + (d2-d1)/2;
 
                 Real coupon = cf[i]->amount()
@@ -124,8 +145,10 @@ namespace QuantLib {
                             const DayCounter& dayCounter,
                             BusinessDayConvention paymentConvention,
                             const std::vector<Real>& notionals,
-                            const Handle<YieldTermStructure>& yieldTS)
-    : RiskyBond(name, ccy, recoveryRate, defaultTS, yieldTS),
+                            const Handle<YieldTermStructure>& yieldTS,
+                            Natural settlementDays)
+    : RiskyBond(name, ccy, recoveryRate, defaultTS, yieldTS,
+                settlementDays, schedule.calendar()),
           schedule_(schedule),
           rate_(rate),
           dayCounter_(dayCounter),
@@ -201,8 +224,10 @@ namespace QuantLib {
                             Integer fixingDays,
                             Real spread,
                             std::vector<Real> notionals,
-                            Handle<YieldTermStructure> yieldTS)
-    : RiskyBond(name, ccy, recoveryRate, defaultTS, yieldTS),
+                            Handle<YieldTermStructure> yieldTS,
+                            Natural settlementDays)
+    : RiskyBond(name, ccy, recoveryRate, defaultTS, yieldTS,
+                settlementDays, schedule.calendar()),
           schedule_(schedule),
           index_(index),
           fixingDays_(fixingDays),
