@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2012, 2013 Klaus Spanderen
+ Copyright (C) 2014 Johannes Göttker-Schnetmann
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -18,7 +19,6 @@
 */
 
 #include <ql/math/functional.hpp>
-#include <ql/instruments/payoffs.hpp>
 #include <ql/methods/finitedifferences/meshers/fdmmesher.hpp>
 #include <ql/methods/finitedifferences/operators/fdmlinearoplayout.hpp>
 #include <ql/methods/finitedifferences/operators/secondderivativeop.hpp>
@@ -30,15 +30,21 @@ namespace QuantLib {
         const boost::shared_ptr<FdmMesher>& mesher,
         const boost::shared_ptr<GeneralizedBlackScholesProcess> & bsProcess,
         Real strike,
+        bool localVol,
+        Real illegalLocalVolOverwrite,
         Size direction)
     : mesher_(mesher),
       rTS_   (bsProcess->riskFreeRate().currentLink()),
       qTS_   (bsProcess->dividendYield().currentLink()),
       volTS_ (bsProcess->blackVolatility().currentLink()),
+      localVol_((localVol) ? bsProcess->localVolatility().currentLink()
+                           : boost::shared_ptr<LocalVolTermStructure>()),
+      x_ ((localVol) ? Array(Exp(mesher->locations(direction))) : Array()),
       dxMap_ (FirstDerivativeOp(direction, mesher)),
       dxxMap_(SecondDerivativeOp(direction, mesher)),
       mapT_  (direction, mesher),
       strike_(strike),
+      illegalLocalVolOverwrite_(illegalLocalVolOverwrite),
       direction_(direction) {
     }
 
@@ -46,11 +52,38 @@ namespace QuantLib {
         const Rate r = rTS_->forwardRate(t1, t2, Continuous).rate();
         const Rate q = qTS_->forwardRate(t1, t2, Continuous).rate();
 
-        const Real v
-            = volTS_->blackForwardVariance(t1, t2, strike_)/(t2-t1);
-        mapT_.axpyb(Array(1, - r + q + 0.5*v), dxMap_,
-                    dxxMap_.mult(0.5*Array(mesher_->layout()->size(), v)),
-                    Array(1, 0.0));
+        if (localVol_) {
+            const boost::shared_ptr<FdmLinearOpLayout> layout=mesher_->layout();
+            const FdmLinearOpIterator endIter = layout->end();
+
+            Array v(layout->size());
+            for (FdmLinearOpIterator iter = layout->begin();
+                iter != endIter; ++iter) {
+                const Size i = iter.index();
+
+                if (illegalLocalVolOverwrite_ < 0.0) {
+                    v[i] = square<Real>()(
+                        localVol_->localVol(0.5*(t1+t2), x_[i], true));
+                }
+                else {
+                    try {
+                        v[i] = square<Real>()(
+                            localVol_->localVol(0.5*(t1+t2), x_[i], true));
+                    } catch (Error&) {
+                        v[i] = square<Real>()(illegalLocalVolOverwrite_);
+                    }
+                }
+            }
+            mapT_.axpyb(Array(1, 1.0), dxMap_.multR(- r + q + 0.5*v),
+                        dxxMap_.multR(0.5*v), Array(1, 0.0));
+        }
+        else {
+            const Real v
+                = volTS_->blackForwardVariance(t1, t2, strike_)/(t2-t1);
+            mapT_.axpyb(Array(1, - r + q + 0.5*v), dxMap_,
+                        dxxMap_.mult(0.5*Array(mesher_->layout()->size(), v)),
+                        Array(1, 0.0));
+        }
     }
 
     Size FdmBlackScholesFwdOp::size() const {
