@@ -2,6 +2,8 @@
 
 /*
  Copyright (C) 2012, 2013 Klaus Spanderen
+ Copyright (C) 2014 Johannes Göttker-Schnetmann
+
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -30,6 +32,9 @@
 #include <ql/experimental/finitedifferences/fdmsquarerootfwdop.hpp>
 #include <ql/experimental/finitedifferences/modtriplebandlinearop.hpp>
 
+#include <boost/math/special_functions/gamma.hpp>
+#include <boost/math/distributions/non_central_chi_squared.hpp>
+
 namespace QuantLib {
 
     FdmSquareRootFwdOp::FdmSquareRootFwdOp(
@@ -40,162 +45,175 @@ namespace QuantLib {
       kappa_(kappa),
       theta_(theta),
       sigma_(sigma),
-      alpha_(1.0 - 2*kappa_*theta_/(sigma_*sigma_)),
       transform_(transform),
       mapX_(transform == Plain ?
-
           new ModTripleBandLinearOp(FirstDerivativeOp(direction_, mesher)
               .mult(kappa*(mesher->locations(direction_)-theta) + sigma*sigma)
               .add(SecondDerivativeOp(direction_, mesher)
                    .mult(0.5*sigma*sigma*mesher->locations(direction_)))
                 .add(Array(mesher->layout()->size(), kappa)))
 
-        : new ModTripleBandLinearOp(
+        : transform == Power ? new ModTripleBandLinearOp(
             SecondDerivativeOp(direction_, mesher)
                .mult(0.5*sigma*sigma*mesher->locations(direction_))
                .add(FirstDerivativeOp(direction_, mesher)
                      .mult(kappa*(mesher->locations(direction_)+theta)))
                .add(Array(mesher->layout()->size(),
                           2*kappa*kappa*theta/(sigma*sigma))))
-      ),
-      v_  (mesher->layout()->dim()[direction_]),
-      vq_ (mesher->layout()->size()),
-      vmq_(mesher->layout()->size()) {
+
+            : new ModTripleBandLinearOp(FirstDerivativeOp(direction_, mesher)
+                    .mult(Exp(-mesher->locations(direction))
+                        *( -0.5*sigma*sigma - kappa*theta) + kappa)
+                    .add(SecondDerivativeOp(direction_, mesher)
+                    .mult(0.5*sigma*sigma*Exp(-mesher->locations(direction))))
+                    .add(kappa*theta*Exp(-mesher->locations(direction))))
+            ),
+      v_  (mesher->layout()->dim()[direction_]) {
 
         const FdmLinearOpIterator endIter = mesher->layout()->end();
         for (FdmLinearOpIterator iter = mesher->layout()->begin();
             iter != endIter; ++iter) {
             const Real v = mesher->location(iter, direction_);
             v_[iter.coordinates()[direction_]] = v;
-            vmq_[iter.index()] = 1.0/(vq_[iter.index()] = std::pow(v, alpha_));
         }
 
         // zero flux boundary condition
-        if (transform_ == Plain) {
-            setLowerBC(mesher);
-            setUpperBC(mesher);
-        }
-        else if (transform == Power) {
-            setTransformLowerBC(mesher);
-            setTransformUpperBC(mesher);
-        }
-    }
-
-
-    void FdmSquareRootFwdOp::setTransformLowerBC(
-        const boost::shared_ptr<FdmMesher>& mesher) {
-
-        const Size n = 1;
-        Real alpha, beta, gamma;
-
-        getTransformCoeff(alpha, beta, gamma, n);
-
-        const Real eta = 1.0/(h(n-1) * (h(n-1)+h(n)) * h(n));
-        const Real a   = -eta*(square<Real>()(h(n-1)+h(n))-h(n-1)*h(n-1));
-        const Real b   =  eta*square<Real>()(h(n-1)+h(n));
-        const Real c   = -eta*h(n-1)*h(n-1);
-        const Real nu  = -sigma_*sigma_*v(n-1)
-                            /(2*(kappa_*v(n-1)+sigma_*sigma_/2*v(n-1)*a));
-
-        const FdmLinearOpIterator endIter = mesher->layout()->end();
-        for (FdmLinearOpIterator iter = mesher->layout()->begin();
-            iter != endIter; ++iter) {
-            if (iter.coordinates()[direction_] == n-1) {
-                const Size idx = iter.index();
-                mapX_->diag()[idx]  = beta + alpha*nu*b;
-                mapX_->upper()[idx] = gamma + alpha*nu*c;
-            }
-        }
-    }
-
-    void FdmSquareRootFwdOp::setTransformUpperBC(
-        const boost::shared_ptr<FdmMesher>& mesher) {
-
-        const Size n = v_.size();
-        Real alpha, beta, gamma;
-
-        getTransformCoeff(alpha, beta, gamma, n);
-
-        const Real eta = 1.0/((h(n)*(h(n)+h(n-1))*h(n-1)));
-        const Real a   =  eta*(square<Real>()(h(n)+h(n-1))-h(n)*h(n));
-        const Real b   = -eta*square<Real>()(h(n)+h(n-1));
-        const Real c   =  eta*h(n)*h(n);
-        const Real nu  = -sigma_*sigma_*v(n+1)
-                            /(2*(kappa_*v(n+1)+sigma_*sigma_/2*v(n+1)*a));
-
-        const FdmLinearOpIterator endIter = mesher->layout()->end();
-        for (FdmLinearOpIterator iter = mesher->layout()->begin();
-            iter != endIter; ++iter) {
-            if (iter.coordinates()[direction_] == n-1) {
-                const Size idx = iter.index();
-                mapX_->diag()[idx]  = beta + gamma*nu*b;
-                mapX_->lower()[idx] = alpha + gamma*nu*c;
-            }
-        }
+        setLowerBC(mesher);
+        setUpperBC(mesher);
     }
 
     void FdmSquareRootFwdOp::setLowerBC(
-       const boost::shared_ptr<FdmMesher>& mesher) {
+        const boost::shared_ptr<FdmMesher>& mesher) {
+        const Size n = 1;
+        Real alpha, beta, gamma;
 
-       const Real beta  = - sigma_*sigma_*v(1)/zeta(1)
-                          + mu(1)*(h(1)-h(0))/zeta(1) + kappa_;
-       const Real gamma =   sigma_*sigma_*v(1)/zetap(1) + mu(1)*h(0)/zetap(1);
+        getCoeff(alpha, beta, gamma, n);
+        const Real f = lowerBoundaryFactor(transform_);
 
-       const Real b = -(h(0)+h(1))/(h(0)*h(1));
-       const Real c =  h(0)/(h(1)*(h(0)+h(1)));
+        const Real b = -(h(n-1)+h(n))/zeta(n);
+        const Real c =  h(n-1)/zetap(n);
 
-       const Real f = f0();
-       const FdmLinearOpIterator endIter = mesher->layout()->end();
-       for (FdmLinearOpIterator iter = mesher->layout()->begin();
-           iter != endIter; ++iter) {
-           if (iter.coordinates()[direction_] == 0) {
-               const Size idx = iter.index();
-               mapX_->diag()[idx]  = beta  + f*b*v(0);
-               mapX_->upper()[idx] = gamma + f*c*v(0);
-           }
-       }
+        const FdmLinearOpIterator endIter = mesher->layout()->end();
+        for (FdmLinearOpIterator iter = mesher->layout()->begin();
+            iter != endIter; ++iter) {
+            if (iter.coordinates()[direction_] == 0) {
+                const Size idx = iter.index();
+                mapX_->diag()[idx]  = beta  + f*b; //*v(n-1);
+                mapX_->upper()[idx] = gamma + f*c; //*v(n-1);
+            }
+        }
     }
 
     void FdmSquareRootFwdOp::setUpperBC(
-       const boost::shared_ptr<FdmMesher>& mesher) {
-       const Size n = v_.size();
+        const boost::shared_ptr<FdmMesher>& mesher) {
+        const Size n = v_.size();
+        Real alpha, beta, gamma;
 
-       const Real alpha =   sigma_*sigma_*v(n)/zetam(n) - mu(n)*h(n)/zetam(n);
-       const Real beta  = - sigma_*sigma_*v(n)/zeta(n)
-                          + mu(n)*(h(n)-h(n-1))/zeta(n) + kappa_;
+        getCoeff(alpha, beta, gamma, n);
+        const Real f = upperBoundaryFactor(transform_);
 
-       const Real b = (h(n)+h(n-1))/(h(n)*h(n-1));
-       const Real c = -h(n)/(h(n-1)*(h(n)+h(n-1)));
+        const Real b = (h(n)+h(n-1))/zeta(n);
+        const Real c = -h(n)/zetam(n);
 
-       const Real f = f1();
-       const FdmLinearOpIterator endIter = mesher->layout()->end();
-       for (FdmLinearOpIterator iter = mesher->layout()->begin();
-           iter != endIter; ++iter) {
-           if (iter.coordinates()[direction_] == n-1) {
-               const Size idx = iter.index();
-               mapX_->diag()[idx] = beta   + f*b*v(n+1);
-               mapX_->lower()[idx] = alpha + f*c*v(n+1);
-           }
-       }
+        const FdmLinearOpIterator endIter = mesher->layout()->end();
+        for (FdmLinearOpIterator iter = mesher->layout()->begin();
+            iter != endIter; ++iter) {
+            if (iter.coordinates()[direction_] == n-1) {
+                const Size idx = iter.index();
+                mapX_->diag()[idx] = beta   + f*b; //*v(n+1);
+                mapX_->lower()[idx] = alpha + f*c; //*v(n+1);
+            }
+        }
     }
 
-    Real FdmSquareRootFwdOp::f0() const {
-        const Real a = -(2*h(0)+h(1))/zetam(1);
-        const Real alpha = sigma_*sigma_*v(1)/zetam(1) - mu(1)*h(1)/zetam(1);
-        const Real nu = a*v(0) + (2*kappa_*(v(0)-theta_) + sigma_*sigma_)
+    Real FdmSquareRootFwdOp::lowerBoundaryFactor(TransformationType transform) const {
+        if (transform == Plain) {
+            return f0Plain();
+        }
+        else if (transform == Power) {
+            return f0Power();
+        }
+        else if (transform == Log) {
+            return f0Log();
+        }
+        else
+            QL_FAIL("unknown transform");
+    }
+
+    Real FdmSquareRootFwdOp::upperBoundaryFactor(TransformationType transform) const {
+        if (transform == Plain) {
+            return f1Plain();
+        }
+        else if (transform == Power) {
+            return f1Power();
+        }
+        else if (transform == Log) {
+            return f1Log();
+        }
+        else
+            QL_FAIL("unknown transform");
+    }
+
+    Real FdmSquareRootFwdOp::f0Plain() const {
+        const Size n = 1;
+        const Real a = -(2*h(n-1)+h(n))/zetam(n);
+        const Real alpha = sigma_*sigma_*v(n)/zetam(n) - mu(n)*h(n)/zetam(n);
+        const Real nu = a*v(n-1) + (2*kappa_*(v(n-1)-theta_) + sigma_*sigma_)
                                         /(sigma_*sigma_);
 
-        return alpha/nu;
+        return alpha/nu*v(n-1);
     }
 
-    Real FdmSquareRootFwdOp::f1() const {
+    Real FdmSquareRootFwdOp::f1Plain() const {
         const Size n = v_.size();
-        const Real a =  (2*h(n)+h(n-1))/(h(n)*(h(n)+h(n-1)));
+        const Real a =  (2*h(n)+h(n-1))/zetap(n);
         const Real gamma = sigma_*sigma_*v(n)/zetap(n) + mu(n)*h(n-1)/zetap(n);
         const Real nu = a*v(n+1) + (2*kappa_*(v(n+1)-theta_) + sigma_*sigma_)
                         /(sigma_*sigma_);
 
-        return gamma/nu;
+        return gamma/nu*v(n+1);
+    }
+
+    Real FdmSquareRootFwdOp::f0Power() const {
+        const Size n = 1;
+        const Real mu = kappa_*(v(n)+theta_);
+        const Real a = -(2*h(n-1)+h(n))/zetam(n);
+        const Real alpha = sigma_*sigma_*v(n)/zetam(n) - mu*h(n)/zetam(n);
+        const Real nu  = a*v(n-1) +2*(kappa_*v(n-1)/(sigma_*sigma_));
+
+        return alpha/nu*v(n-1);
+    }
+
+    Real FdmSquareRootFwdOp::f1Power() const {
+        const Size n = v_.size();
+        const Real mu = kappa_*(v(n)+theta_);
+        const Real a =  (2*h(n)+h(n-1))/zetap(n);
+        const Real gamma = sigma_*sigma_*v(n)/zetap(n) + mu*h(n-1)/zetap(n);
+        const Real nu = a*v(n+1) +2*(kappa_*v(n+1)/(sigma_*sigma_));
+
+        return gamma/nu*v(n+1); 
+    }
+
+    Real FdmSquareRootFwdOp::f0Log() const {
+        const Size n = 1;
+        const Real mu = ((-kappa_*theta_-sigma_*sigma_/2.0)*exp(-v(1))+kappa_);
+        const Real a = -(2*h(n-1)+h(n))/zetam(n);
+        const Real alpha = sigma_*sigma_*exp(-v(n))/zetam(n) - mu*h(n)/zetam(n);
+        const Real nu = a*exp(-v(n-1)) + 2*kappa_*(1-theta_*exp(-v(n-1)))
+                        /(sigma_*sigma_);
+
+        return alpha/nu*exp(-v(n-1));
+    }
+
+    Real FdmSquareRootFwdOp::f1Log() const {
+        const Size n = v_.size();
+        const Real mu = ((-kappa_*theta_-sigma_*sigma_/2.0)*exp(-v(n))+kappa_);
+        const Real a =  (2*h(n)+h(n-1))/zetap(n);
+        const Real gamma = sigma_*sigma_*exp(-v(n))/zetap(n) + mu*h(n-1)/zetap(n);
+        const Real nu = a*exp(-v(n+1)) + 2*kappa_*(1-theta_*exp(-v(n+1)))
+                        /(sigma_*sigma_);
+
+        return gamma/nu*exp(-v(n+1));
     }
 
     Real FdmSquareRootFwdOp::v(Size i) const {
@@ -203,7 +221,12 @@ namespace QuantLib {
             return v_[i-1];
         }
         else if (i == 0) {
-            return std::max(0.5*v_[0], v_[0] - 0.5 * (v_[1] - v_[0]));
+            if (transform_ == Log) {
+                return 2*v_[0] - v_[1];
+//              log(std::max(0.5*exp(v_[0]), exp(v_[0] - 0.01 * (v_[1] - v_[0]))));
+            } else {
+                return std::max(0.5*v_[0], v_[0] - 0.01 * (v_[1] - v_[0]));
+            }
         }
         else if (i == v_.size()+1) {
             return v_.back() + (v_.back() - *(v_.end()-2));
@@ -235,23 +258,48 @@ namespace QuantLib {
     void FdmSquareRootFwdOp::setTime(Time, Time) {
     }
 
-    void FdmSquareRootFwdOp::getTransformCoeff(Real& alpha, Real& beta,
+    void FdmSquareRootFwdOp::getCoeff(Real& alpha, Real& beta,
                                                Real& gamma, Size n) const {
-        alpha = (sigma_*sigma_*v(n) - kappa_*(theta_+v(n))*h(n))/zetam(n);
+        if (transform_ == Plain) {
+            getCoeffPlain(alpha, beta, gamma, n);
+        }
+        else if (transform_ == Power) {
+            getCoeffPower(alpha, beta, gamma, n);
+        }
+        else if (transform_ == Log) {
+            getCoeffLog(alpha, beta, gamma, n);
+        } 
+    }
 
-        beta = (-sigma_*sigma_*v(n) + kappa_*(theta_+v(n))*(h(n)-h(n-1)))/zeta(n)
+    void FdmSquareRootFwdOp::getCoeffPlain(Real& alpha, Real& beta,
+                                               Real& gamma, Size n) const {
+        alpha =   sigma_*sigma_*v(n)/zetam(n) - mu(n)*h(n)/zetam(n);
+        beta  = - sigma_*sigma_*v(n)/zeta(n)
+                    + mu(n)*(h(n)-h(n-1))/zeta(n) + kappa_;
+        gamma =   sigma_*sigma_*v(n)/zetap(n) + mu(n)*h(n-1)/zetap(n);
+
+    }
+
+    void FdmSquareRootFwdOp::getCoeffLog(Real& alpha, Real& beta,
+                                               Real& gamma, Size n) const {
+        const Real mu = ((-kappa_*theta_-sigma_*sigma_/2.0)*exp(-v(n))+kappa_);
+        alpha =   sigma_*sigma_*exp(-v(n))/zetam(n) - mu*h(n)/zetam(n);
+        beta  = - sigma_*sigma_*exp(-v(n))/zeta(n)
+                          + mu*(h(n)-h(n-1))/zeta(n) + kappa_*theta_*exp(-v(n));
+        gamma =   sigma_*sigma_*exp(-v(n))/zetap(n) + mu*h(n-1)/zetap(n);
+    }
+
+    void FdmSquareRootFwdOp::getCoeffPower(Real& alpha, Real& beta,
+                                               Real& gamma, Size n) const {
+        const Real mu = kappa_*(theta_+v(n));
+        alpha = (sigma_*sigma_*v(n) - mu*h(n))/zetam(n);
+        beta = (-sigma_*sigma_*v(n) + mu*(h(n)-h(n-1)))/zeta(n)
                                 + 2*kappa_*kappa_*theta_/(sigma_*sigma_);
-
-        gamma=  (sigma_*sigma_*v(n) + kappa_*(theta_+v(n))*h(n-1))/zetap(n);
+        gamma=  (sigma_*sigma_*v(n) + mu*h(n-1))/zetap(n);
     }
 
     Disposable<Array> FdmSquareRootFwdOp::apply(const Array& p) const {
-        if (transform_ != Power) {
-            return mapX_->apply(p);
-        }
-        else {
-            return vmq_*mapX_->apply(vq_*p);
-        }
+        return mapX_->apply(p);
     }
 
     Disposable<Array> FdmSquareRootFwdOp::apply_mixed(const Array& r) const {
@@ -261,12 +309,7 @@ namespace QuantLib {
     Disposable<Array> FdmSquareRootFwdOp::apply_direction(
         Size direction, const Array& r) const {
         if (direction == direction_) {
-            if (transform_ != Power) {
-                return mapX_->apply(r);
-            }
-            else {
-                return vmq_*mapX_->apply(vq_*r);
-            }
+            return mapX_->apply(r);
         }
         else {
             Array retVal(r.size(), 0.0);
@@ -276,12 +319,7 @@ namespace QuantLib {
     Disposable<Array> FdmSquareRootFwdOp::solve_splitting(
         Size direction, const Array& r, Real dt) const {
         if (direction == direction_) {
-            if (transform_ != Power) {
-                return mapX_->solve_splitting(r, dt, 1.0);
-            }
-            else {
-                return vmq_*mapX_->solve_splitting(vq_*r, dt, 1.0);
-            }
+            return mapX_->solve_splitting(r, dt, 1.0);
         }
         else {
             Array retVal(r);
@@ -291,12 +329,7 @@ namespace QuantLib {
 
     Disposable<Array> FdmSquareRootFwdOp::preconditioner(
         const Array& r, Real dt) const {
-        if (transform_ != Power) {
-            return solve_splitting(direction_, r, dt);
-        }
-        else {
-            return vmq_*solve_splitting(direction_, vq_*r, dt);
-        }
+        return solve_splitting(direction_, r, dt);
     }
 
     #if !defined(QL_NO_UBLAS_SUPPORT)
