@@ -35,7 +35,7 @@
 #include <ql/methods/finitedifferences/operators/fdmlinearoplayout.hpp>
 #include <ql/experimental/finitedifferences/fdmklugeextousolver.hpp>
 #include <ql/methods/finitedifferences/meshers/exponentialjump1dmesher.hpp>
-#include <ql/experimental/finitedifferences/fdmvppstepcondition.hpp>
+#include <ql/experimental/finitedifferences/fdmvppstepconditionfactory.hpp>
 #include <ql/experimental/finitedifferences/fdsimpleklugeextouvppengine.hpp>
 #include <ql/methods/finitedifferences/stepconditions/fdmstepconditioncomposite.hpp>
 #include <ql/methods/finitedifferences/meshers/fdmsimpleprocess1dmesher.hpp>
@@ -51,16 +51,16 @@ namespace QuantLib {
           public:
             FdmSparkSpreadInnerValue(
                 const boost::shared_ptr<BasketPayoff>& basketPayoff,
-                const boost::shared_ptr<FdmInnerValueCalculator>& gasPrice,
+                const boost::shared_ptr<FdmInnerValueCalculator>& fuelPrice,
                 const boost::shared_ptr<FdmInnerValueCalculator>& powerPrice)
             : basketPayoff_(basketPayoff),
-              gasPrice_(gasPrice),
+              fuelPrice_(fuelPrice),
               powerPrice_(powerPrice) { }
 
             Real innerValue(const FdmLinearOpIterator& iter, Time t) {
                 Array s(2);
                 s[0] = powerPrice_->innerValue(iter, t);
-                s[1] = gasPrice_->innerValue(iter, t);
+                s[1] = fuelPrice_->innerValue(iter, t);
 
                 return (*basketPayoff_)(s);
             }
@@ -70,7 +70,7 @@ namespace QuantLib {
 
           private:
             const boost::shared_ptr<BasketPayoff> basketPayoff_;
-            const boost::shared_ptr<FdmInnerValueCalculator> gasPrice_;
+            const boost::shared_ptr<FdmInnerValueCalculator> fuelPrice_;
             const boost::shared_ptr<FdmInnerValueCalculator> powerPrice_;
         };
     }
@@ -79,21 +79,21 @@ namespace QuantLib {
     FdSimpleKlugeExtOUVPPEngine::FdSimpleKlugeExtOUVPPEngine(
         const boost::shared_ptr<KlugeExtOUProcess>& process,
         const boost::shared_ptr<YieldTermStructure>& rTS,
-        Real carbonPrice,
-        Size tGrid, Size xGrid, Size yGrid, Size gGrid,
-        const boost::shared_ptr<Shape>& gasShape,
+        const boost::shared_ptr<Shape>& fuelShape,
         const boost::shared_ptr<Shape>& powerShape,
+        Real fuelCostAddon,
+        Size tGrid, Size xGrid, Size yGrid, Size gGrid,
         const FdmSchemeDesc& schemeDesc)
-    : process_    (process),
-      rTS_        (rTS),
-      carbonPrice_(carbonPrice),
-      gasShape_   (gasShape),
-      powerShape_ (powerShape),
-      tGrid_      (tGrid),
-      xGrid_      (xGrid),
-      yGrid_      (yGrid),
-      gGrid_      (gGrid),
-      schemeDesc_ (schemeDesc) {
+    : process_      (process),
+      rTS_          (rTS),
+      fuelCostAddon_(fuelCostAddon),
+      fuelShape_     (fuelShape),
+      powerShape_   (powerShape),
+      tGrid_        (tGrid),
+      xGrid_        (xGrid),
+      yGrid_        (yGrid),
+      gGrid_        (gGrid),
+      schemeDesc_   (schemeDesc) {
     }
 
     void FdSimpleKlugeExtOUVPPEngine::calculate() const {
@@ -103,17 +103,9 @@ namespace QuantLib {
 
         QL_REQUIRE(swingExercise, "Swing exercise supported only");
 
-        const Size nStates = 2*arguments_.tMinUp + arguments_.tMinDown;
-
-        // 1. Layout
-        std::vector<Size> dim;
-        dim.push_back(xGrid_);
-        dim.push_back(yGrid_);
-        dim.push_back(gGrid_);
-        dim.push_back(nStates);
-        const boost::shared_ptr<FdmLinearOpLayout> layout(
-            new FdmLinearOpLayout(dim));
+        const FdmVPPStepConditionFactory stepConditionFactory(arguments_);
 
+        // 1. Exercise definition
         const std::vector<Time> exerciseTimes
             = swingExercise->exerciseTimes(rTS_->dayCounter(),
                                            rTS_->referenceDate());
@@ -140,15 +132,10 @@ namespace QuantLib {
                                          process_->getExtOUProcess(),maturity));
 
         const boost::shared_ptr<Fdm1dMesher> exerciseMesher(
-            new Uniform1dMesher(1.0, nStates, nStates));
+            stepConditionFactory.stateMesher());
 
-        std::vector<boost::shared_ptr<Fdm1dMesher> > meshers;
-        meshers.push_back(xMesher);
-        meshers.push_back(yMesher);
-        meshers.push_back(gMesher);
-        meshers.push_back(exerciseMesher);
         const boost::shared_ptr<FdmMesher> mesher (
-            new FdmMesherComposite(layout, meshers));
+            new FdmMesherComposite(xMesher, yMesher, gMesher, exerciseMesher));
 
         // 3. Calculator
         const boost::shared_ptr<FdmInnerValueCalculator> zeroInnerValue(
@@ -157,9 +144,9 @@ namespace QuantLib {
         const boost::shared_ptr<Payoff> zeroStrikeCall(
             new PlainVanillaPayoff(Option::Call, 0.0));
 
-        const boost::shared_ptr<FdmInnerValueCalculator> gasPrice(
+        const boost::shared_ptr<FdmInnerValueCalculator> fuelPrice(
             new FdmExpExtOUInnerValueCalculator(zeroStrikeCall,
-                                                mesher, gasShape_, 2));
+                                                mesher, fuelShape_, 2));
 
         const boost::shared_ptr<FdmInnerValueCalculator> powerPrice(
             new FdmExtOUJumpModelInnerValue(zeroStrikeCall,mesher,powerShape_));
@@ -167,7 +154,7 @@ namespace QuantLib {
         const boost::shared_ptr<FdmInnerValueCalculator> sparkSpread(
             new FdmSparkSpreadInnerValue(
                 boost::dynamic_pointer_cast<BasketPayoff>(arguments_.payoff),
-                gasPrice, powerPrice));
+                fuelPrice, powerPrice));
 
         // 4. Step conditions
         std::list<std::vector<Time> > stoppingTimes;
@@ -175,20 +162,19 @@ namespace QuantLib {
 
         // 4.1 Bermudan step conditions
         stoppingTimes.push_back(exerciseTimes);
-        stepConditions.push_back(boost::shared_ptr<StepCondition<Array> >(
-            new FdmVPPStepCondition(arguments_.heatRate,
-                                    arguments_.pMin, arguments_.pMax,
-                                    arguments_.tMinUp, arguments_.tMinDown,
-                                    arguments_.startUpFuel,
-                                    arguments_.startUpFixCost,
-                                    carbonPrice_, 3,
-                                    mesher, gasPrice, sparkSpread)));
+        const FdmVPPStepConditionMesher mesh = { 3u, mesher };
+        
+        const boost::shared_ptr<FdmVPPStepCondition> stepCondition(
+            stepConditionFactory.build(mesh, fuelCostAddon_,
+                                       fuelPrice, sparkSpread));
 
-        boost::shared_ptr<FdmStepConditionComposite> conditions(
-                new FdmStepConditionComposite(stoppingTimes, stepConditions));
+        stepConditions.push_back(stepCondition);
+
+        const boost::shared_ptr<FdmStepConditionComposite> conditions(
+            new FdmStepConditionComposite(stoppingTimes, stepConditions));
 
         // 5. Boundary conditions
-        const std::vector<boost::shared_ptr<FdmDirichletBoundary> > boundaries;
+        const FdmBoundaryConditionSet boundaries;
 
         // 6. set-up solver
         FdmSolverDesc solverDesc = { mesher, boundaries, conditions,
@@ -202,8 +188,19 @@ namespace QuantLib {
         x[0] = process_->initialValues()[0];
         x[1] = process_->initialValues()[1];
         x[2] = process_->initialValues()[2];
-        x[3] = (Real) arguments_.initialState;
+        
+        const Real tol = 1e-8;
+        const Real maxExerciseValue = exerciseMesher->locations().back();
+        const Real minExerciseValue = exerciseMesher->locations().front();
 
-        results_.value = solver->valueAt(x);
+        Array results(exerciseMesher->size());
+        for (Size i=0; i < results.size(); ++i) {
+
+            x[3] = std::max(minExerciseValue + tol,
+                            std::min(exerciseMesher->location(i),
+                                     maxExerciseValue - tol));
+            results[i] = solver->valueAt(x);
+        }
+        results_.value = stepCondition->maxValue(results);
     }
 }
