@@ -20,13 +20,10 @@
 #include <ql/experimental/inflation/yoyoptionlethelpers.hpp>
 #include <ql/instruments/makeyoyinflationcapfloor.hpp>
 
+#include <ql/utilities/null_deleter.hpp>
+
 namespace QuantLib {
 
-    namespace {
-        void no_deletion(void*) {}
-    }
-
-
     YoYOptionletHelper::YoYOptionletHelper(
                   const Handle<Quote>& price,
                   Real notional,
@@ -83,8 +80,8 @@ namespace QuantLib {
         const bool own = false;
         // create a handle to the new vol surface
         Handle<YoYOptionletVolatilitySurface> volSurf(
-              boost::shared_ptr<YoYOptionletVolatilitySurface>(v,no_deletion),
-              own);
+            boost::shared_ptr<YoYOptionletVolatilitySurface>(v, null_deleter()),
+            own);
         // in this case all we need to do is reset the vol in the pricer
         // we must do it because the surface is a different one each time
         // i.e. the pointer (handle) changes, not just what it points to
