@@ -30,7 +30,6 @@ Mathl. Comput. Modelling, 967-973, 1989
 #include <ql/math/optimization/constraint.hpp>
 #include <ql/experimental/math/hybridsimulatedannealingfunctors.hpp>
 #include <ql/math/optimization/levenbergmarquardt.hpp>
-#include <boost/make_shared.hpp>
 
 namespace QuantLib {
 
@@ -80,21 +79,24 @@ namespace QuantLib {
         HybridSimulatedAnnealing(const Sampler &sampler,
             const Probability &probability,
             const Temperature &temperature,
-            const Reannealing &reannealing,
+            const Reannealing &reannealing = ReannealingTrivial(),
             Real startTemperature = 200.0,
             Real endTemperature = 0.01,
             Size reAnnealSteps = 50,
             ResetScheme resetScheme = ResetToBestPoint,
             Size resetSteps = 150,
             boost::shared_ptr<OptimizationMethod> localOptimizer
-            = boost::make_shared<LevenbergMarquardt>(),
+            = boost::shared_ptr<OptimizationMethod>(),
             LocalOptimizeScheme optimizeScheme = EveryBestPoint)
             : sampler_(sampler), probability_(probability),
             temperature_(temperature), reannealing_(reannealing),
             startTemperature_(startTemperature), endTemperature_(endTemperature),
             reAnnealSteps_(reAnnealSteps == 0 ? QL_MAX_INTEGER : reAnnealSteps), resetScheme_(resetScheme),
             resetSteps_(resetSteps == 0 ? QL_MAX_INTEGER : resetSteps), localOptimizer_(localOptimizer),
-            optimizeScheme_(localOptimizer ? optimizeScheme : NoLocalOptimize) {}
+            optimizeScheme_(localOptimizer ? optimizeScheme : NoLocalOptimize) {
+            if (!localOptimizer)
+                localOptimizer.reset(new LevenbergMarquardt);
+        }
 
         EndCriteria::Type minimize(Problem &P, const EndCriteria &endCriteria);
     private:
@@ -138,37 +140,39 @@ namespace QuantLib {
         {
             //Draw a new sample point
             sampler_(newPoint, currentPoint, currentTemperature);
-
-            //Evaluate new point
-            Real newValue = P.value(newPoint);
-
-            //Determine if new point is accepted
-            if (probability_(currentValue, newValue, currentTemperature)) {
-                if (optimizeScheme_ == EveryNewPoint) {
-                    P.setCurrentValue(newPoint);
-                    P.setFunctionValue(newValue);
-                    localOptimizer_->minimize(P, endCriteria);
-                    newPoint = P.currentValue();
-                    newValue = P.functionValue();
+            try{
+                //Evaluate new point
+                Real newValue = P.value(newPoint);
+				
+                //Determine if new point is accepted
+                if (probability_(currentValue, newValue, currentTemperature)) {
+                    if (optimizeScheme_ == EveryNewPoint) {
+                        P.setCurrentValue(newPoint);
+                        P.setFunctionValue(newValue);
+                        localOptimizer_->minimize(P, endCriteria);
+                        newPoint = P.currentValue();
+                        newValue = P.functionValue();
+                    }
+                    currentPoint = newPoint;
+                    currentValue = newValue;
                 }
-                currentPoint = newPoint;
-                currentValue = newValue;
-            }
 
-            //Check if we have a new best point
-            if (newValue < bestValue) {
-                if (optimizeScheme_ == EveryBestPoint) {
-                    P.setCurrentValue(newPoint);
-                    P.setFunctionValue(newValue);
-                    localOptimizer_->minimize(P, endCriteria);
-                    newPoint = P.currentValue();
-                    newValue = P.functionValue();
+                //Check if we have a new best point
+                if (newValue < bestValue) {
+                    if (optimizeScheme_ == EveryBestPoint) {
+                        P.setCurrentValue(newPoint);
+                        P.setFunctionValue(newValue);
+                        localOptimizer_->minimize(P, endCriteria);
+                        newPoint = P.currentValue();
+                        newValue = P.functionValue();
+                    }
+                    kStationary = 0;
+                    bestValue = newValue;
+                    bestPoint = newPoint;
                 }
-                kStationary = 0;
-                bestValue = newValue;
-                bestPoint = newPoint;
+            } catch(...){
+                //Do nothing, move on to new draw
             }
-
             //Increase steps
             k++;
             kStationary++;
@@ -188,11 +192,11 @@ namespace QuantLib {
                 switch (resetScheme_) {
                 case NoResetScheme:
                     break;
-                case ResetToBestPoint:
+                case ResetToOrigin:
                     currentPoint = startingPoint;
                     currentValue = startingValue;
                     break;
-                case ResetToOrigin:
+                case ResetToBestPoint:
                     currentPoint = bestPoint;
                     currentValue = bestValue;
                     break;
@@ -207,6 +211,7 @@ namespace QuantLib {
             for (Size i = 0; i < n; i++)
                 temperatureBreached = temperatureBreached && currentTemperature[i] < endTemperature_;
         }
+        
         //Change end criteria type if appropriate
         if (k > maxK)
             ecType = EndCriteria::MaxIterations;
@@ -219,8 +224,12 @@ namespace QuantLib {
         return ecType;
     }
 
-    typedef HybridSimulatedAnnealing<SamplerGaussian, ProbabilityBoltzmannDownhill, TemperatureExponential, ReannealingFiniteDifferences> GaussianSimulatedAnnealing;
-    typedef HybridSimulatedAnnealing<SamplerVeryFastAnnealing, ProbabilityBoltzmannDownhill, TemperatureVeryFastAnnealing, ReannealingFiniteDifferences> VeryFastSimulatedAnnealing;
+    typedef HybridSimulatedAnnealing<SamplerGaussian, ProbabilityBoltzmannDownhill, TemperatureExponential, ReannealingTrivial> GaussianSimulatedAnnealing;
+    typedef HybridSimulatedAnnealing<SamplerLogNormal, ProbabilityBoltzmannDownhill, TemperatureExponential, ReannealingTrivial> LogNormalSimulatedAnnealing;
+    typedef HybridSimulatedAnnealing<SamplerMirrorGaussian, ProbabilityBoltzmannDownhill, TemperatureExponential, ReannealingTrivial> MirrorGaussianSimulatedAnnealing;
+    typedef HybridSimulatedAnnealing<SamplerGaussian, ProbabilityBoltzmannDownhill, TemperatureExponential, ReannealingFiniteDifferences> GaussianSimulatedReAnnealing;
+    typedef HybridSimulatedAnnealing<SamplerVeryFastAnnealing, ProbabilityBoltzmannDownhill, TemperatureVeryFastAnnealing, ReannealingTrivial> VeryFastSimulatedAnnealing;
+    typedef HybridSimulatedAnnealing<SamplerVeryFastAnnealing, ProbabilityBoltzmannDownhill, TemperatureVeryFastAnnealing, ReannealingFiniteDifferences> VeryFastSimulatedReAnnealing;
 }
 
 #endif
