@@ -21,13 +21,23 @@
 #include <ql/processes/ornsteinuhlenbeckprocess.hpp>
 #include <ql/experimental/processes/extendedornsteinuhlenbeckprocess.hpp>
 
-#include <boost/lambda/bind.hpp>
-#include <boost/lambda/lambda.hpp>
-
-using namespace boost::lambda;
-
 namespace QuantLib {
 
+    namespace {
+
+        class integrand {
+            boost::function<Real (Real)> b;
+            Real speed;
+          public:
+            integrand(const boost::function<Real (Real)>& b, Real speed)
+            : b(b), speed(speed) {}
+            Real operator()(Real x) const {
+                return b(x) * std::exp(speed*x);
+            }
+        };
+
+    }
+
     ExtendedOrnsteinUhlenbeckProcess::ExtendedOrnsteinUhlenbeckProcess(
                                         Real speed, Volatility vol, Real x0,
                                         const boost::function<Real (Real)>& b,
@@ -95,10 +105,8 @@ namespace QuantLib {
           case GaussLobatto:
               return ouProcess_->expectation(t0, x0, dt)
                   + speed_*std::exp(-speed_*(t0+dt))
-                  * GaussLobattoIntegral(100000, intEps_)(
-                         boost::lambda::bind(b_, boost::lambda::_1)
-                        *boost::lambda::bind(std::ptr_fun<Real, Real>(std::exp),
-                                          speed_*boost::lambda::_1), t0, t0+dt);
+                  * GaussLobattoIntegral(100000, intEps_)(integrand(b_, speed_),
+                                                          t0, t0+dt);
             break;
           default:
             QL_FAIL("unknown discretization scheme");
