@@ -121,9 +121,6 @@ class NoArbSabrModel {
 
     Real absorptionProbability() const { return absProb_; }
 
-    QL_DEPRECATED
-    static void checkAbsorptionMatrix();
-
     private:
     Real p(const Real f) const;
     Real forwardError(const Real forward) const;
