@@ -207,7 +207,7 @@ template <typename Evaluation>
 void ZabrSmileSection<Evaluation>::init2(ZabrFullFd) {
     callPrices_.resize(strikes_.size());
 #pragma omp parallel for
-    for (Size i = 0; i < strikes_.size(); i++) {
+    for (long i = 0; i < (long)strikes_.size(); i++) {
         callPrices_[i] = model_->fullFdPrice(strikes_[i]);
     }
 }
