@@ -1,7 +1,7 @@
 /* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
 /*
- Copyright (C) 2006 Ferdinando Ametrano
+ Copyright (C) 2006, 2011 Ferdinando Ametrano
  Copyright (C) 2000, 2001, 2002, 2003 RiskMap srl
  Copyright (C) 2003, 2004, 2005, 2006, 2007 StatPro Italia srl
 
@@ -33,14 +33,10 @@ namespace QuantLib {
                                          const Calendar& fixingCalendar,
                                          const DayCounter& dayCounter)
     : familyName_(familyName), tenor_(tenor), fixingDays_(fixingDays),
-      fixingCalendar_(fixingCalendar), currency_(currency),
-      dayCounter_(dayCounter) {
+      currency_(currency), dayCounter_(dayCounter),
+      fixingCalendar_(fixingCalendar) {
         tenor_.normalize();
-        registerWith(Settings::instance().evaluationDate());
-        registerWith(IndexManager::instance().notifier(name()));
-    }
 
-    std::string InterestRateIndex::name() const {
         std::ostringstream out;
         out << familyName_;
         if (tenor_ == 1*Days) {
@@ -56,62 +52,45 @@ namespace QuantLib {
             out << io::short_period(tenor_);
         }
         out << " " << dayCounter_.name();
-        return out.str();
-    }
+        name_ = out.str();
 
-    Calendar InterestRateIndex::fixingCalendar() const {
-        return fixingCalendar_;
-    }
-
-    bool InterestRateIndex::isValidFixingDate(const Date& fixingDate) const {
-        return fixingCalendar().isBusinessDay(fixingDate);
+        registerWith(Settings::instance().evaluationDate());
+        registerWith(IndexManager::instance().notifier(name()));
     }
 
     Rate InterestRateIndex::fixing(const Date& fixingDate,
                                    bool forecastTodaysFixing) const {
+
         QL_REQUIRE(isValidFixingDate(fixingDate),
                    "Fixing date " << fixingDate << " is not valid");
+
         Date today = Settings::instance().evaluationDate();
-        bool enforceTodaysHistoricFixings =
-            Settings::instance().enforcesTodaysHistoricFixings();
-        if (fixingDate < today ||
-            (fixingDate == today && enforceTodaysHistoricFixings && !forecastTodaysFixing)) {
+
+        if (fixingDate>today ||
+            (fixingDate==today && forecastTodaysFixing))
+            return forecastFixing(fixingDate);
+
+        if (fixingDate<today ||
+            Settings::instance().enforcesTodaysHistoricFixings()) {
             // must have been fixed
-            Rate pastFixing =
-                IndexManager::instance().getHistory(name())[fixingDate];
-            QL_REQUIRE(pastFixing != Null<Real>(),
+            // do not catch exceptions
+            Rate result = pastFixing(fixingDate);
+            QL_REQUIRE(result != Null<Real>(),
                        "Missing " << name() << " fixing for " << fixingDate);
-            return pastFixing;
+            return result;
         }
-        if ((fixingDate == today) && !forecastTodaysFixing) {
+
+        try {
             // might have been fixed
-            try {
-                Rate pastFixing =
-                    IndexManager::instance().getHistory(name())[fixingDate];
-                if (pastFixing != Null<Real>())
-                    return pastFixing;
-                else
-                    ;   // fall through and forecast
-            } catch (Error&) {
-                ;       // fall through and forecast
-            }
+            Rate result = pastFixing(fixingDate);
+            if (result!=Null<Real>())
+                return result;
+            else
+                ;   // fall through and forecast
+        } catch (Error&) {
+                ;   // fall through and forecast
         }
-        // forecast
         return forecastFixing(fixingDate);
     }
 
-    Date InterestRateIndex::valueDate(const Date& fixingDate) const {
-        QL_REQUIRE(isValidFixingDate(fixingDate),
-                   "Fixing date " << fixingDate << " is not valid");
-        return fixingCalendar().advance(fixingDate, fixingDays_, Days);
-    }
-
-    Date InterestRateIndex::fixingDate(const Date& valueDate) const {
-        Date fixingDate = fixingCalendar().advance(valueDate,
-            -static_cast<Integer>(fixingDays_), Days);
-        QL_ENSURE(isValidFixingDate(fixingDate),
-                  "fixing date " << fixingDate << " is not valid");
-        return fixingDate;
-    }
-
 }
