@@ -3,6 +3,8 @@
 /*
  Copyright (C) 2009, 2014, 2015 Ferdinando Ametrano
  Copyright (C) 2015 Paolo Mazzocchi
+ Copyright (C) 2017 Joseph Jeisman
+ Copyright (C) 2017 Fabrice Lecuyer
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -36,12 +38,15 @@ namespace QuantLib {
       settlementDays_(2),
       calendar_(overnightIndex->fixingCalendar()),
       paymentFrequency_(Annual),
+      paymentCalendar_(Calendar()),
+      paymentAdjustment_(Following),
+      paymentLag_(0),
       rule_(DateGeneration::Backward),
       // any value here for endOfMonth_ would not be actually used
       isDefaultEOM_(true),
       type_(OvernightIndexedSwap::Payer), nominal_(1.0),
       overnightSpread_(0.0),
-      fixedDayCount_(overnightIndex->dayCounter()) {}
+      fixedDayCount_(overnightIndex->dayCounter()), telescopicValueDates_(false) {}
 
     MakeOIS::operator OvernightIndexedSwap() const {
         shared_ptr<OvernightIndexedSwap> ois = *this;
@@ -68,7 +73,7 @@ namespace QuantLib {
         }
 
         // OIS end of month default
-        bool usedEndOfMonth = 
+        bool usedEndOfMonth =
             isDefaultEOM_ ? calendar_.isEndOfMonth(startDate) : endOfMonth_;
 
         Date endDate = terminationDate_;
@@ -96,7 +101,9 @@ namespace QuantLib {
                                       schedule,
                                       0.0, // fixed rate
                                       fixedDayCount_,
-                                      overnightIndex_, overnightSpread_);
+                                      overnightIndex_, overnightSpread_,
+                                      paymentLag_, paymentAdjustment_,
+                                      paymentCalendar_, telescopicValueDates_);
             if (engine_ == 0) {
                 Handle<YieldTermStructure> disc =
                                     overnightIndex_->forwardingTermStructure();
@@ -117,7 +124,9 @@ namespace QuantLib {
             OvernightIndexedSwap(type_, nominal_,
                                  schedule,
                                  usedFixedRate, fixedDayCount_,
-                                 overnightIndex_, overnightSpread_));
+                                 overnightIndex_, overnightSpread_,
+                                 paymentLag_, paymentAdjustment_,
+                                 paymentCalendar_, telescopicValueDates_));
 
         if (engine_ == 0) {
             Handle<YieldTermStructure> disc =
@@ -171,6 +180,21 @@ namespace QuantLib {
         return *this;
     }
 
+    MakeOIS& MakeOIS::withPaymentAdjustment(BusinessDayConvention convention) {
+        paymentAdjustment_ = convention;
+        return *this;
+    }
+
+    MakeOIS& MakeOIS::withPaymentLag(Natural lag) {
+        paymentLag_ = lag;
+        return *this;
+    }
+
+    MakeOIS& MakeOIS::withPaymentCalendar(const Calendar& cal) {
+        paymentCalendar_ = cal;
+        return *this;
+    }
+
     MakeOIS& MakeOIS::withRule(DateGeneration::Rule r) {
         rule_ = r;
         if (r==DateGeneration::Zero)
@@ -208,4 +232,11 @@ namespace QuantLib {
         return *this;
     }
 
+    MakeOIS& MakeOIS::withTelescopicValueDates(bool telescopicValueDates) {
+        telescopicValueDates_ = telescopicValueDates;
+        return *this;
+
+    }
+
+
 }
