@@ -2,6 +2,8 @@
 
 /*
  Copyright (C) 2009 Ferdinando Ametrano
+ Copyright (C) 2017 Joseph Jeisman
+ Copyright (C) 2017 Fabrice Lecuyer
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -54,6 +56,10 @@ namespace QuantLib {
         MakeOIS& withRule(DateGeneration::Rule r);
 
         MakeOIS& withPaymentFrequency(Frequency f);
+        MakeOIS& withPaymentAdjustment(BusinessDayConvention convention);
+        MakeOIS& withPaymentLag(Natural lag);
+        MakeOIS& withPaymentCalendar(const Calendar& cal);
+
         MakeOIS& withEndOfMonth(bool flag = true);
 
         MakeOIS& withFixedLegDayCount(const DayCounter& dc);
@@ -62,6 +68,9 @@ namespace QuantLib {
 
         MakeOIS& withDiscountingTermStructure(
                   const Handle<YieldTermStructure>& discountingTermStructure);
+
+        MakeOIS &withTelescopicValueDates(bool telescopicValueDates);
+
         MakeOIS& withPricingEngine(
                               const boost::shared_ptr<PricingEngine>& engine);
       private:
@@ -75,6 +84,10 @@ namespace QuantLib {
         Calendar calendar_;
 
         Frequency paymentFrequency_;
+        Calendar paymentCalendar_;
+        BusinessDayConvention paymentAdjustment_;
+        Natural paymentLag_;
+
         DateGeneration::Rule rule_;
         bool endOfMonth_, isDefaultEOM_;
 
@@ -85,6 +98,8 @@ namespace QuantLib {
         DayCounter fixedDayCount_;
 
         boost::shared_ptr<PricingEngine> engine_;
+
+        bool telescopicValueDates_;
     };
 
 }
