@@ -3,6 +3,8 @@
 /*
  Copyright (C) 2009 Roland Lichters
  Copyright (C) 2009 Ferdinando Ametrano
+ Copyright (C) 2017 Joseph Jeisman
+ Copyright (C) 2017 Fabrice Lecuyer
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -31,12 +33,19 @@ namespace QuantLib {
                     Rate fixedRate,
                     const DayCounter& fixedDC,
                     const boost::shared_ptr<OvernightIndex>& overnightIndex,
-                    Spread spread)
+                    Spread spread,
+                    Natural paymentLag,
+                    BusinessDayConvention paymentAdjustment,
+                    Calendar paymentCalendar,
+                    bool telescopicValueDates)
     : Swap(2), type_(type),
       nominals_(std::vector<Real>(1, nominal)),
       paymentFrequency_(schedule.tenor().frequency()),
+      paymentCalendar_(paymentCalendar.empty() ? schedule.calendar() : paymentCalendar),
+      paymentAdjustment_(paymentAdjustment), paymentLag_(paymentLag),
       fixedRate_(fixedRate), fixedDC_(fixedDC),
-      overnightIndex_(overnightIndex), spread_(spread) {
+      overnightIndex_(overnightIndex), spread_(spread),
+      telescopicValueDates_(telescopicValueDates) {
 
           initialize(schedule);
 
@@ -49,11 +58,18 @@ namespace QuantLib {
                     Rate fixedRate,
                     const DayCounter& fixedDC,
                     const boost::shared_ptr<OvernightIndex>& overnightIndex,
-                    Spread spread)
+                    Spread spread,
+                    Natural paymentLag,
+                    BusinessDayConvention paymentAdjustment,
+                    Calendar paymentCalendar,
+                    bool telescopicValueDates)
     : Swap(2), type_(type), nominals_(nominals),
       paymentFrequency_(schedule.tenor().frequency()),
+      paymentCalendar_(paymentCalendar.empty() ? schedule.calendar() : paymentCalendar),
+      paymentAdjustment_(paymentAdjustment), paymentLag_(paymentLag),
       fixedRate_(fixedRate), fixedDC_(fixedDC),
-      overnightIndex_(overnightIndex), spread_(spread) {
+      overnightIndex_(overnightIndex), spread_(spread),
+      telescopicValueDates_(telescopicValueDates) {
 
           initialize(schedule);
 
@@ -64,11 +80,18 @@ namespace QuantLib {
             fixedDC_ = overnightIndex_->dayCounter();
         legs_[0] = FixedRateLeg(schedule)
             .withNotionals(nominals_)
-            .withCouponRates(fixedRate_, fixedDC_);
+            .withCouponRates(fixedRate_, fixedDC_)
+            .withPaymentLag(paymentLag_)
+            .withPaymentAdjustment(paymentAdjustment_)
+            .withPaymentCalendar(paymentCalendar_);
 
-        legs_[1] = OvernightLeg(schedule, overnightIndex_)
+		legs_[1] = OvernightLeg(schedule, overnightIndex_)
             .withNotionals(nominals_)
-            .withSpreads(spread_);
+            .withSpreads(spread_)
+            .withTelescopicValueDates(telescopicValueDates_)
+            .withPaymentLag(paymentLag_)
+            .withPaymentAdjustment(paymentAdjustment_)
+            .withPaymentCalendar(paymentCalendar_);
 
         for (Size j=0; j<2; ++j) {
             for (Leg::iterator i = legs_[j].begin(); i!= legs_[j].end(); ++i)
