@@ -49,7 +49,7 @@ namespace QuantLib {
     public:
         template <class xContainer, class yContainer, class vContainer>
         GeneralLinearLeastSquares(const xContainer & x,
-                                  const yContainer &y, const vContainer & v);
+                                  const yContainer & y, const vContainer & v);
 
         template<class xIterator, class yIterator, class vIterator>
         GeneralLinearLeastSquares(xIterator xBegin, xIterator xEnd,
@@ -72,6 +72,16 @@ namespace QuantLib {
         Array a_, err_, residuals_, standardErrors_;
 
         template <class xIterator, class yIterator, class vIterator>
+        void calculate(
+            xIterator xBegin, xIterator xEnd,
+            yIterator yBegin, yIterator yEnd,
+            vIterator vBegin);
+
+        /*! \deprecated Use the overload taking 5 parameters.
+                        Deprecated in version 1.10.
+        */
+        template <class xIterator, class yIterator, class vIterator>
+        QL_DEPRECATED
         void calculate(
             xIterator xBegin, xIterator xEnd,
             yIterator yBegin, yIterator yEnd,
@@ -80,13 +90,13 @@ namespace QuantLib {
 
     template <class xContainer, class yContainer, class vContainer> inline
     GeneralLinearLeastSquares::GeneralLinearLeastSquares(const xContainer & x,
-                                                         const yContainer &y,
+                                                         const yContainer & y,
                                                          const vContainer & v)
     : a_(v.size(), 0.0),
       err_(v.size(), 0.0),
       residuals_(y.size()),
       standardErrors_(v.size()) {
-        calculate(x.begin(), x.end(), y.begin(), y.end(), v.begin(), v.end());
+        calculate(x.begin(), x.end(), y.begin(), y.end(), v.begin());
     }
 
     template<class xIterator, class yIterator, class vIterator> inline
@@ -98,14 +108,14 @@ namespace QuantLib {
       err_(a_.size(), 0.0),
       residuals_(std::distance(yBegin, yEnd)),
       standardErrors_(a_.size()) {
-        calculate(xBegin, xEnd, yBegin, yEnd, vBegin, vEnd);
+        calculate(xBegin, xEnd, yBegin, yEnd, vBegin);
     }
 
 
     template <class xIterator, class yIterator, class vIterator>
     void GeneralLinearLeastSquares::calculate(xIterator xBegin, xIterator xEnd,
                                               yIterator yBegin, yIterator yEnd,
-                                              vIterator vBegin, vIterator vEnd) {
+                                              vIterator vBegin) {
 
         const Size n = residuals_.size();
         const Size m = err_.size();
@@ -150,6 +160,14 @@ namespace QuantLib {
             std::bind1st(std::multiplies<Real>(),
             std::sqrt(chiSq/(n-2))));
     }
+
+    template <class xIterator, class yIterator, class vIterator>
+    void GeneralLinearLeastSquares::calculate(xIterator xBegin, xIterator xEnd,
+                                              yIterator yBegin, yIterator yEnd,
+                                              vIterator vBegin, vIterator) {
+        calculate(xBegin, xEnd, yBegin, yEnd, vBegin);
+    }
+
 }
 
 #endif
