@@ -24,11 +24,9 @@
 
 namespace QuantLib {
 
-    Disposable<Array> SteepestDescent::getUpdatedDirection(
-                                                   Problem &P,
-                                                   Real fold,
-                                                   Real gold2,
-                                                   const Array& oldGradient) {
+    Disposable<Array> SteepestDescent::getUpdatedDirection(const Problem&,
+                                                           Real,
+                                                           const Array&) {
         return -lineSearch_->lastGradient();
     }
 
