@@ -26,6 +26,7 @@
 #include <ql/methods/finitedifferences/operators/secondderivativeop.hpp>
 #include <ql/methods/finitedifferences/operators/fdmhestonhullwhiteop.hpp>
 #include <ql/methods/finitedifferences/operators/secondordermixedderivativeop.hpp>
+#include <boost/make_shared.hpp>
 
 namespace QuantLib {
 
@@ -83,7 +84,7 @@ namespace QuantLib {
       theta_(hestonProcess->theta()),
       sigma_(hestonProcess->sigma()),
       rho_(hestonProcess->rho()),
-      hwModel_(new HullWhite(hestonProcess->riskFreeRate(),
+      hwModel_(boost::make_shared<HullWhite>(hestonProcess->riskFreeRate(),
                              hwProcess->a(), hwProcess->sigma())),
       hestonCorrMap_(SecondOrderMixedDerivativeOp(0, 1, mesher)
                      .mult(rho_*sigma_*mesher->locations(1))),
