@@ -21,7 +21,7 @@
 #include <ql/methods/finitedifferences/solvers/fdm2dimsolver.hpp>
 #include <ql/methods/finitedifferences/operators/fdm2dblackscholesop.hpp>
 #include <ql/methods/finitedifferences/solvers/fdm2dblackscholessolver.hpp>
-
+#include <boost/make_shared.hpp>
 
 namespace QuantLib {
 
@@ -49,7 +49,7 @@ namespace QuantLib {
     void Fdm2dBlackScholesSolver::performCalculations() const {
         
         boost::shared_ptr<Fdm2dBlackScholesOp> op(
-                new Fdm2dBlackScholesOp(solverDesc_.mesher,
+			boost::make_shared<Fdm2dBlackScholesOp>(solverDesc_.mesher,
                                         p1_.currentLink(), 
                                         p2_.currentLink(), 
                                         correlation_,
@@ -57,8 +57,7 @@ namespace QuantLib {
                                         localVol_,
                                         illegalLocalVolOverwrite_));
 
-        solver_ = boost::shared_ptr<Fdm2DimSolver>(
-                            new Fdm2DimSolver(solverDesc_, schemeDesc_, op));
+        solver_ = boost::make_shared<Fdm2DimSolver>(solverDesc_, schemeDesc_, op);
     }
 
     Real Fdm2dBlackScholesSolver::valueAt(Real u, Real v) const {
