@@ -31,6 +31,7 @@
 #include <ql/methods/finitedifferences/schemes/expliciteulerscheme.hpp>
 #include <ql/methods/finitedifferences/schemes/modifiedcraigsneydscheme.hpp>
 #include <ql/methods/finitedifferences/stepconditions/fdmstepconditioncomposite.hpp>
+#include <boost/make_shared.hpp>
 
 namespace QuantLib {
     
@@ -75,10 +76,9 @@ namespace QuantLib {
         const FdmSchemeDesc& schemeDesc)
     : map_(map), bcSet_(bcSet),
       condition_((condition) ? condition 
-                             : boost::shared_ptr<FdmStepConditionComposite>(
-                                 new FdmStepConditionComposite(
+                             : boost::make_shared<FdmStepConditionComposite>(
                                      std::list<std::vector<Time> >(),
-                                     FdmStepConditionComposite::Conditions()))),
+                                     FdmStepConditionComposite::Conditions())),
       schemeDesc_(schemeDesc) {
      }
         
