@@ -122,11 +122,12 @@ namespace QuantLib {
         product_->reset();
         Real principalInNumerairePortfolio = 1.0;
 
-        if (storeRates) {
-            std::fill(constraintsActive_.begin(),
-                      constraintsActive_.end(),
-                      false);
-        }
+        if (storeRates)
+            constraintsActive_ =false;
+        //            std::fill(constraintsActive_.begin(),
+        //                    constraintsActive_.end(),
+        //                  false);
+        //  }
 
         bool done = false;
         do {
