@@ -31,11 +31,7 @@ namespace QuantLib {
             Impl(Real k, Real theta) : k_(k), theta_(theta) {}
             bool test(const Array& params) const {
                 Real sigma = params[0];
-                if (sigma <= 0.0)
-                    return false;
-                if (sigma*sigma >= 2.0*k_*theta_)
-                    return false;
-                return true;
+                return (sigma > 0.0) && (sigma*sigma < 2.0*k_*theta_);
             }
         };
       public:
@@ -45,13 +41,17 @@ namespace QuantLib {
     };
 
     CoxIngersollRoss::CoxIngersollRoss(Rate r0, Real theta,
-                                       Real k, Real sigma)
+                                       Real k, Real sigma,
+                                       bool withFellerConstraint)
     : OneFactorAffineModel(4),
       theta_(arguments_[0]), k_(arguments_[1]),
       sigma_(arguments_[2]), r0_(arguments_[3]) {
         theta_ = ConstantParameter(theta, PositiveConstraint());
         k_ = ConstantParameter(k, PositiveConstraint());
-        sigma_ = ConstantParameter(sigma, VolatilityConstraint(k,theta));
+        if (withFellerConstraint)
+            sigma_ = ConstantParameter(sigma, VolatilityConstraint(k,theta));
+        else
+            sigma_ = ConstantParameter(sigma, PositiveConstraint());
         r0_ = ConstantParameter(r0, PositiveConstraint());
     }
 
@@ -109,8 +109,8 @@ namespace QuantLib {
         Real ncps = 2.0*rho*rho*x0()*std::exp(h*t)/(rho+psi+b);
         Real ncpt = 2.0*rho*rho*x0()*std::exp(h*t)/(rho+psi);
 
-        NonCentralChiSquareDistribution chis(df, ncps);
-        NonCentralChiSquareDistribution chit(df, ncpt);
+        NonCentralCumulativeChiSquareDistribution chis(df, ncps);
+        NonCentralCumulativeChiSquareDistribution chit(df, ncpt);
 
         Real z = std::log(A(t,s)/strike)/b;
         Real call = discountS*chis(2.0*z*(rho+psi+b)) -
