@@ -42,7 +42,7 @@ namespace QuantLib {
                    || polynomType == LsmBasisSystem::Laguerre
                    || polynomType == LsmBasisSystem::Hermite
                    || polynomType == LsmBasisSystem::Hyperbolic
-                   || polynomType == LsmBasisSystem::Chebyshev2th,
+                   || polynomType == LsmBasisSystem::Chebyshev2nd,
                    "insufficient polynom type");
         const boost::shared_ptr<BasketPayoff> basketPayoff
             = boost::dynamic_pointer_cast<BasketPayoff>(payoff_);
@@ -50,7 +50,6 @@ namespace QuantLib {
 
         const boost::shared_ptr<StrikedTypePayoff> strikePayoff
             = boost::dynamic_pointer_cast<StrikedTypePayoff>(basketPayoff->basePayoff());
-        QL_REQUIRE(basketPayoff, "payoff not a basket strike payoff");
 
         if (strikePayoff) {
             scalingValue_/=strikePayoff->strike();
