@@ -56,11 +56,48 @@ namespace QuantLib {
       public:
         AnalyticDigitalAmericanEngine(
                     const boost::shared_ptr<GeneralizedBlackScholesProcess>&);
-        void calculate() const;
+        virtual void calculate() const;
+        virtual bool knock_in() const {
+           return true;
+        }
       private:
         boost::shared_ptr<GeneralizedBlackScholesProcess> process_;
     };
 
+    //! Analytic pricing engine for American Knock-out options with digital payoff
+    /*! \ingroup vanillaengines
+
+        \todo add more greeks (as of now only delta and rho available)
+
+        \test
+        - the correctness of the returned value in case of
+          cash-or-nothing at-hit digital payoff is tested by
+          reproducing results available in literature.
+        - the correctness of the returned value in case of
+          asset-or-nothing at-hit digital payoff is tested by
+          reproducing results available in literature.
+        - the correctness of the returned value in case of
+          cash-or-nothing at-expiry digital payoff is tested by
+          reproducing results available in literature.
+        - the correctness of the returned value in case of
+          asset-or-nothing at-expiry digital payoff is tested by
+          reproducing results available in literature.
+        - the correctness of the returned greeks in case of
+          cash-or-nothing at-hit digital payoff is tested by
+          reproducing numerical derivatives.
+    */
+    class AnalyticDigitalAmericanKOEngine : 
+                              public AnalyticDigitalAmericanEngine {
+      public:
+        AnalyticDigitalAmericanKOEngine(
+                    const boost::shared_ptr<GeneralizedBlackScholesProcess> 
+                                 &engine):
+        AnalyticDigitalAmericanEngine(engine) {}
+        virtual bool knock_in() const {
+           return false;
+        }
+    };
+
 }
 
 
