@@ -61,8 +61,8 @@ namespace QuantLib {
     template <class TS>
     class BootstrapHelper : public Observer, public Observable {
       public:
-        BootstrapHelper(const Handle<Quote>& quote);
-        BootstrapHelper(Real quote);
+        explicit BootstrapHelper(const Handle<Quote>& quote);
+        explicit BootstrapHelper(Real quote);
         virtual ~BootstrapHelper() {}
         //! \name BootstrapHelper interface
         //@{
@@ -127,8 +127,8 @@ namespace QuantLib {
     template <class TS>
     class RelativeDateBootstrapHelper : public BootstrapHelper<TS> {
       public:
-        RelativeDateBootstrapHelper(const Handle<Quote>& quote);
-        RelativeDateBootstrapHelper(Real quote);
+        explicit RelativeDateBootstrapHelper(const Handle<Quote>& quote);
+        explicit RelativeDateBootstrapHelper(Real quote);
         //! \name Observer interface
         //@{
         void update() {
