@@ -42,16 +42,6 @@ namespace QuantLib {
             constructors.
         */
         //@{
-        /*! \warning term structures initialized by means of this
-                     constructor must manage their own reference date
-                     by overriding the referenceDate() method.
-            \deprecated
-        */
-        QL_DEPRECATED
-        LocalVolTermStructure(const Calendar& cal,
-                              BusinessDayConvention bdc = Following,
-                              const DayCounter& dc = DayCounter());
-
         //! default constructor
         /*! \warning term structures initialized by means of this
                      constructor must manage their own reference date
