@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2008 Ferdinando Ametrano
  Copyright (C) 2004, 2005, 2007 StatPro Italia srl
+ Copyright (C) 2015 Peter Caspers
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -35,29 +36,33 @@ namespace QuantLib {
     class ConstantOptionletVolatility : public OptionletVolatilityStructure {
       public:
         //! floating reference date, floating market data
-        ConstantOptionletVolatility(Natural settlementDays,
-                                    const Calendar& cal,
+        ConstantOptionletVolatility(Natural settlementDays, const Calendar &cal,
                                     BusinessDayConvention bdc,
-                                    const Handle<Quote>& volatility,
-                                    const DayCounter& dc);
+                                    const Handle< Quote > &volatility,
+                                    const DayCounter &dc,
+                                    VolatilityType type = ShiftedLognormal,
+                                    Real displacement = 0.0);
         //! fixed reference date, floating market data
-        ConstantOptionletVolatility(const Date& referenceDate,
-                                    const Calendar& cal,
+        ConstantOptionletVolatility(const Date &referenceDate,
+                                    const Calendar &cal,
                                     BusinessDayConvention bdc,
-                                    const Handle<Quote>& volatility,
-                                    const DayCounter& dc);
+                                    const Handle< Quote > &volatility,
+                                    const DayCounter &dc,
+                                    VolatilityType type = ShiftedLognormal,
+                                    Real displacement = 0.0);
         //! floating reference date, fixed market data
-        ConstantOptionletVolatility(Natural settlementDays,
-                                    const Calendar& cal,
+        ConstantOptionletVolatility(Natural settlementDays, const Calendar &cal,
                                     BusinessDayConvention bdc,
-                                    Volatility volatility,
-                                    const DayCounter& dc);
+                                    Volatility volatility, const DayCounter &dc,
+                                    VolatilityType type = ShiftedLognormal,
+                                    Real displacement = 0.0);
         //! fixed reference date, fixed market data
-        ConstantOptionletVolatility(const Date& referenceDate,
-                                    const Calendar& cal,
+        ConstantOptionletVolatility(const Date &referenceDate,
+                                    const Calendar &cal,
                                     BusinessDayConvention bdc,
-                                    Volatility volatility,
-                                    const DayCounter& dc);
+                                    Volatility volatility, const DayCounter &dc,
+                                    VolatilityType type = ShiftedLognormal,
+                                    Real displacement = 0.0);
         //! \name TermStructure interface
         //@{
         Date maxDate() const;
@@ -67,6 +72,9 @@ namespace QuantLib {
         Real minStrike() const;
         Real maxStrike() const;
         //@}
+        VolatilityType volatilityType() const;
+        Real displacement() const;
+
       protected:
         boost::shared_ptr<SmileSection> smileSectionImpl(const Date& d) const;
         boost::shared_ptr<SmileSection> smileSectionImpl(Time) const;
@@ -74,6 +82,8 @@ namespace QuantLib {
                                   Rate) const;
       private:
         Handle<Quote> volatility_;
+        VolatilityType type_;
+        Real displacement_;
     };
 
 
@@ -91,6 +101,14 @@ namespace QuantLib {
         return QL_MAX_REAL;
     }
 
+    inline VolatilityType
+    ConstantOptionletVolatility::volatilityType() const {
+        return type_;
+    }
+
+    inline Real ConstantOptionletVolatility::displacement() const {
+        return displacement_;
+    }
 }
 
 #endif
