@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2007 Ferdinando Ametrano
  Copyright (C) 2007 Giorgio Facchinetti
+ Copyright (C) 2015 Peter Caspers
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -25,16 +26,14 @@ using std::vector;
 
 namespace QuantLib {
 
-    OptionletStripper::OptionletStripper(
-            const boost::shared_ptr<CapFloorTermVolSurface>& termVolSurface,
-            const boost::shared_ptr<IborIndex>& iborIndex,
-            const Handle<YieldTermStructure>& discount, 
-            VolatilityType type,
-            Real displacement) 
-   : termVolSurface_(termVolSurface),
-     iborIndex_(iborIndex), discount_(discount),
-     nStrikes_(termVolSurface->strikes().size()), 
-     volatilityType_(type), displacement_(displacement) {
+OptionletStripper::OptionletStripper(
+    const boost::shared_ptr< CapFloorTermVolSurface > &termVolSurface,
+    const boost::shared_ptr< IborIndex > &iborIndex,
+    const Handle< YieldTermStructure > &discount, const VolatilityType type,
+    const Real displacement)
+    : termVolSurface_(termVolSurface), iborIndex_(iborIndex),
+      discount_(discount), nStrikes_(termVolSurface->strikes().size()),
+      volatilityType_(type), displacement_(displacement) {
 
         if (volatilityType_ == Normal) {
             QL_REQUIRE(displacement_ == 0.0,
@@ -157,7 +156,7 @@ namespace QuantLib {
         return displacement_;
     }
 
-    VolatilityType OptionletStripper::volatilityType() const{
+    VolatilityType OptionletStripper::volatilityType() const {
         return volatilityType_;
     }
 
