@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2008 Ferdinando Ametrano
  Copyright (C) 2006, 2007 StatPro Italia srl
+ Copyright (C) 2015 Peter Caspers
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -30,9 +31,11 @@ namespace QuantLib {
                                                     const Calendar& cal,
                                                     BusinessDayConvention bdc,
                                                     const Handle<Quote>& vol,
-                                                    const DayCounter& dc)
+                                                    const DayCounter& dc,
+                                                    const VolatilityType type,
+                                                    const Real shift)
     : SwaptionVolatilityStructure(settlementDays, cal, bdc, dc),
-      volatility_(vol), maxSwapTenor_(100*Years) {
+      volatility_(vol), maxSwapTenor_(100*Years), volatilityType_(type), shift_(shift) {
         registerWith(volatility_);
     }
 
@@ -42,9 +45,11 @@ namespace QuantLib {
                                                     const Calendar& cal,
                                                     BusinessDayConvention bdc,
                                                     const Handle<Quote>& vol,
-                                                    const DayCounter& dc)
+                                                    const DayCounter& dc,
+                                                    const VolatilityType type,
+                                                    const Real shift)
     : SwaptionVolatilityStructure(referenceDate, cal, bdc, dc),
-      volatility_(vol), maxSwapTenor_(100*Years) {
+      volatility_(vol), maxSwapTenor_(100*Years), volatilityType_(type), shift_(shift) {
         registerWith(volatility_);
     }
 
@@ -54,10 +59,12 @@ namespace QuantLib {
                                                     const Calendar& cal,
                                                     BusinessDayConvention bdc,
                                                     Volatility vol,
-                                                    const DayCounter& dc)
+                                                    const DayCounter& dc,
+                                                    const VolatilityType type,
+                                                    const Real shift)
     : SwaptionVolatilityStructure(settlementDays, cal, bdc, dc),
       volatility_(boost::shared_ptr<Quote>(new SimpleQuote(vol))),
-      maxSwapTenor_(100*Years) {}
+      maxSwapTenor_(100*Years), volatilityType_(type), shift_(shift) {}
 
     // fixed reference date, fixed market data
     ConstantSwaptionVolatility::ConstantSwaptionVolatility(
@@ -65,25 +72,29 @@ namespace QuantLib {
                                                     const Calendar& cal,
                                                     BusinessDayConvention bdc,
                                                     Volatility vol,
-                                                    const DayCounter& dc)
+                                                    const DayCounter& dc,
+                                                    const VolatilityType type,
+                                                    const Real shift)
     : SwaptionVolatilityStructure(referenceDate, cal, bdc, dc),
       volatility_(boost::shared_ptr<Quote>(new SimpleQuote(vol))),
-      maxSwapTenor_(100*Years) {}
+      maxSwapTenor_(100*Years), volatilityType_(type), shift_(shift) {}
 
     boost::shared_ptr<SmileSection>
     ConstantSwaptionVolatility::smileSectionImpl(const Date& d,
                                                  const Period&) const {
         Volatility atmVol = volatility_->value();
-        return boost::shared_ptr<SmileSection>(new
-            FlatSmileSection(d, atmVol, dayCounter(), referenceDate()));
+        return boost::shared_ptr<SmileSection>(
+            new FlatSmileSection(d, atmVol, dayCounter(), referenceDate(),
+                                 Null<Rate>(), volatilityType_, shift_));
     }
 
     boost::shared_ptr<SmileSection>
     ConstantSwaptionVolatility::smileSectionImpl(Time optionTime,
                                                  Time) const {
         Volatility atmVol = volatility_->value();
-        return boost::shared_ptr<SmileSection>(new
-            FlatSmileSection(optionTime, atmVol, dayCounter()));
+        return boost::shared_ptr<SmileSection>(
+            new FlatSmileSection(optionTime, atmVol, dayCounter(), Null<Rate>(),
+                                 volatilityType_, shift_));
     }
 
     Volatility ConstantSwaptionVolatility::volatilityImpl(const Date&,
