@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2008 Ferdinando Ametrano
  Copyright (C) 2006, 2007 StatPro Italia srl
+ Copyright (C) 2015 Peter Caspers
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -40,25 +41,33 @@ namespace QuantLib {
                                    const Calendar& cal,
                                    BusinessDayConvention bdc,
                                    const Handle<Quote>& volatility,
-                                   const DayCounter& dc);
+                                   const DayCounter& dc,
+                                   const VolatilityType type = ShiftedLognormal,
+                                   const Real shift = 0.0);
         //! fixed reference date, floating market data
         ConstantSwaptionVolatility(const Date& referenceDate,
                                    const Calendar& cal,
                                    BusinessDayConvention bdc,
                                    const Handle<Quote>& volatility,
-                                   const DayCounter& dc);
+                                   const DayCounter& dc,
+                                   const VolatilityType type = ShiftedLognormal,
+                                   const Real shift = 0.0);
         //! floating reference date, fixed market data
         ConstantSwaptionVolatility(Natural settlementDays,
                                    const Calendar& cal,
                                    BusinessDayConvention bdc,
                                    Volatility volatility,
-                                   const DayCounter& dc);
+                                   const DayCounter& dc,
+                                   const VolatilityType type = ShiftedLognormal,
+                                   const Real shift = 0.0);
         //! fixed reference date, fixed market data
         ConstantSwaptionVolatility(const Date& referenceDate,
                                    const Calendar& cal,
                                    BusinessDayConvention bdc,
                                    Volatility volatility,
-                                   const DayCounter& dc);
+                                   const DayCounter& dc,
+                                   const VolatilityType type = ShiftedLognormal,
+                                   const Real shift = 0.0);
         //! \name TermStructure interface
         //@{
         Date maxDate() const;
@@ -72,6 +81,8 @@ namespace QuantLib {
         //@{
         const Period& maxSwapTenor() const;
         //@}
+        //! volatility type
+        VolatilityType volatilityType() const;
       protected:
         boost::shared_ptr<SmileSection> smileSectionImpl(const Date&,
                                                          const Period&) const;
@@ -83,9 +94,12 @@ namespace QuantLib {
         Volatility volatilityImpl(Time,
                                   Time,
                                   Rate) const;
+        Real shiftImpl(Time optionTime, Time swapLength) const;
       private:
         Handle<Quote> volatility_;
         Period maxSwapTenor_;
+        VolatilityType volatilityType_;
+        Real shift_;
     };
 
 
@@ -107,6 +121,16 @@ namespace QuantLib {
         return maxSwapTenor_;
     }
 
+    inline VolatilityType ConstantSwaptionVolatility::volatilityType() const {
+        return volatilityType_;
+    }
+
+    inline Real ConstantSwaptionVolatility::shiftImpl(Time optionTime, Time swapLength) const {
+        // consistency check
+        SwaptionVolatilityStructure::shiftImpl(optionTime, swapLength);
+        return shift_;
+    }
+
 }
 
 #endif
