@@ -33,10 +33,22 @@ namespace QuantLib {
                     const Period& tenor, // swap maturity
                     const Handle<Quote>& fixedRate,
                     const boost::shared_ptr<OvernightIndex>& overnightIndex,
-                    const Handle<YieldTermStructure>& discount)
+                    const Handle<YieldTermStructure>& discount,
+                    bool telescopicValueDates,
+                    Natural paymentLag,
+                    BusinessDayConvention paymentConvention,
+                    Frequency paymentFrequency,
+                    const Calendar& paymentCalendar,
+                    const Period& forwardStart, 
+                    const Spread overnightSpread)
     : RelativeDateRateHelper(fixedRate),
       settlementDays_(settlementDays), tenor_(tenor),
-      overnightIndex_(overnightIndex), discountHandle_(discount) {
+      overnightIndex_(overnightIndex), discountHandle_(discount),
+      telescopicValueDates_(telescopicValueDates),
+      paymentLag_(paymentLag), paymentConvention_(paymentConvention),
+      paymentFrequency_(paymentFrequency),
+      paymentCalendar_(paymentCalendar),
+      forwardStart_(forwardStart), overnightSpread_(overnightSpread) {
         registerWith(overnightIndex_);
         registerWith(discountHandle_);
         initializeDates();
@@ -53,9 +65,15 @@ namespace QuantLib {
 
         // input discount curve Handle might be empty now but it could
         //    be assigned a curve later; use a RelinkableHandle here
-        swap_ = MakeOIS(tenor_, clonedOvernightIndex, 0.0)
+        swap_ = MakeOIS(tenor_, clonedOvernightIndex, 0.0, forwardStart_)
             .withDiscountingTermStructure(discountRelinkableHandle_)
-            .withSettlementDays(settlementDays_);
+            .withSettlementDays(settlementDays_)
+            .withTelescopicValueDates(telescopicValueDates_)
+            .withPaymentLag(paymentLag_)
+            .withPaymentAdjustment(paymentConvention_)
+            .withPaymentFrequency(paymentFrequency_)
+            .withPaymentCalendar(paymentCalendar_)
+            .withOvernightLegSpread(overnightSpread_);
 
         earliestDate_ = swap_->startDate();
         latestDate_ = swap_->maturityDate();
@@ -98,8 +116,10 @@ namespace QuantLib {
                     const Date& endDate,
                     const Handle<Quote>& fixedRate,
                     const boost::shared_ptr<OvernightIndex>& overnightIndex,
-                    const Handle<YieldTermStructure>& discount)
-    : RateHelper(fixedRate), discountHandle_(discount) {
+                    const Handle<YieldTermStructure>& discount,
+                    bool telescopicValueDates)
+        : RateHelper(fixedRate), discountHandle_(discount),
+          telescopicValueDates_(telescopicValueDates) {
 
         registerWith(overnightIndex);
         registerWith(discountHandle_);
@@ -116,7 +136,8 @@ namespace QuantLib {
         swap_ = MakeOIS(Period(), clonedOvernightIndex, 0.0)
             .withDiscountingTermStructure(discountRelinkableHandle_)
             .withEffectiveDate(startDate)
-            .withTerminationDate(endDate);
+            .withTerminationDate(endDate)
+            .withTelescopicValueDates(telescopicValueDates_);
 
         earliestDate_ = swap_->startDate();
         latestDate_ = swap_->maturityDate();
