@@ -96,8 +96,8 @@ namespace QuantLib {
             weekend for the given market.
         */
         bool isWeekend(Weekday w) const;
-        /*! Returns <tt>true</tt> iff the date is last business day for the
-            month in given market.
+        /*! Returns <tt>true</tt> iff in the given market, the date is on
+            or after the last business day for that month.
         */
         bool isEndOfMonth(const Date& d) const;
         //! last business day of the month to which the given date belongs
@@ -196,11 +196,19 @@ namespace QuantLib {
 
     inline bool Calendar::isBusinessDay(const Date& d) const {
         QL_REQUIRE(impl_, "no implementation provided");
-        if (impl_->addedHolidays.find(d) != impl_->addedHolidays.end())
+
+#ifdef QL_HIGH_RESOLUTION_DATE
+        const Date _d(d.dayOfMonth(), d.month(), d.year());
+#else
+        const Date& _d = d;
+#endif
+
+        if (impl_->addedHolidays.find(_d) != impl_->addedHolidays.end())
             return false;
-        if (impl_->removedHolidays.find(d) != impl_->removedHolidays.end())
+        if (impl_->removedHolidays.find(_d) != impl_->removedHolidays.end())
             return true;
-        return impl_->isBusinessDay(d);
+
+        return impl_->isBusinessDay(_d);
     }
 
     inline bool Calendar::isEndOfMonth(const Date& d) const {
