@@ -107,6 +107,8 @@ namespace QuantLib {
             || (d == 15 && m == November)
             // Black Consciousness Day
             || (d == 20 && m == November && y >= 2007)
+            // Christmas Eve
+            || (d == 24 && m == December)
             // Christmas
             || (d == 25 && m == December)
             // Passion of Christ
