@@ -63,6 +63,8 @@ namespace QuantLib {
             || (y == 2013 && d <= 3 && m == January)
             || (y == 2014 && d == 1 && m == January)
             || (y == 2015 && d <= 3 && m == January)
+            || (y == 2017 && d == 2 && m == January)
+            || (y == 2018 && d == 1 && m == January)
             // Chinese New Year
             || (y == 2004 && d >= 19 && d <= 28 && m == January)
             || (y == 2005 && d >=  7 && d <= 15 && m == February)
@@ -79,6 +81,9 @@ namespace QuantLib {
             || (y == 2014 && d <= 6 && m == February)
             || (y == 2015 && d >= 18 && d <= 24 && m == February)
             || (y == 2016 && d >= 8 && d <= 12 && m == February)
+            || (y == 2017 && ((d >= 27 && m == January) ||
+                              (d <= 2 && m == February)))
+            || (y == 2018 && (d >= 15 && d <= 21 && m == February))
             // Ching Ming Festival
             || (y <= 2008 && d == 4 && m == April)
             || (y == 2009 && d == 6 && m == April)
@@ -89,6 +94,8 @@ namespace QuantLib {
             || (y == 2014 && d == 7 && m == April)
             || (y == 2015 && d >= 5 && d <= 6 && m == April)
             || (y == 2016 && d == 4 && m == April)
+            || (y == 2017 && d >= 3 && d <= 4 && m == April)
+            || (y == 2018 && d >= 5 && d <= 6 && m == April)
             // Labor Day
             || (y <= 2007 && d >= 1 && d <= 7 && m == May)
             || (y == 2008 && d >= 1 && d <= 2 && m == May)
@@ -102,6 +109,8 @@ namespace QuantLib {
             || (y == 2014 && d >= 1 && d <=3 && m == May)
             || (y == 2015 && d == 1 && m == May)
             || (y == 2016 && d >= 1 && d <=2 && m == May)
+            || (y == 2017 && d == 1 && m == May)
+            || (y == 2018 && ((d == 30 && m == April) || (d == 1 && m == May)))
             // Tuen Ng Festival
             || (y <= 2008 && d == 9 && m == June)
             || (y == 2009 && (d == 28 || d == 29) && m == May)
@@ -112,6 +121,8 @@ namespace QuantLib {
             || (y == 2014 && d == 2 && m == June)
             || (y == 2015 && d == 22 && m == June)
             || (y == 2016 && d >= 9 && d <= 10 && m == June)
+            || (y == 2017 && d >= 29 && d <= 30 && m == May)
+            || (y == 2018 && d == 18 && m == June)
             // Mid-Autumn Festival
             || (y <= 2008 && d == 15 && m == September)
             || (y == 2010 && d >= 22 && d <= 24 && m == September)
@@ -121,6 +132,7 @@ namespace QuantLib {
             || (y == 2014 && d == 8 && m == September)
             || (y == 2015 && d == 27 && m == September)
             || (y == 2016 && d >= 15 && d <= 16 && m == September)
+            || (y == 2018 && d == 24 && m == September)
             // National Day
             || (y <= 2007 && d >= 1 && d <= 7 && m == October)
             || (y == 2008 && ((d >= 29 && m == September) ||
@@ -133,6 +145,8 @@ namespace QuantLib {
             || (y == 2014 && d >= 1 && d <= 7 && m == October)
             || (y == 2015 && d >= 1 && d <= 7 && m == October)
             || (y == 2016 && d >= 3 && d <= 7 && m == October)
+            || (y == 2017 && d >= 2 && d <= 6 && m == October)
+            || (y == 2018 && d >= 1 && d <= 5 && m == October)
             // 70th anniversary of the victory of anti-Japaneses war
             || (y == 2015 && d >= 3 && d <= 4 && m == September)
             )
@@ -236,7 +250,20 @@ namespace QuantLib {
             Date(12,June,2016),
             Date(18,September,2016),
             Date(8,October,2016),
-            Date(9,October,2016)
+            Date(9,October,2016),
+            // 2017
+            Date(22,January,2017),
+            Date(4,February,2017),
+            Date(1,April,2017),
+            Date(27,May,2017),
+            Date(30,September,2017),
+            // 2018
+            Date(11, February, 2018),
+            Date(24, February, 2018),
+            Date(8, April, 2018),
+            Date(28, April, 2018),
+            Date(29, September, 2018),
+            Date(30, September, 2018)
         };
         static const Size n =
             sizeof(working_weekends)/sizeof(working_weekends[0]);
