@@ -37,19 +37,32 @@ namespace QuantLib {
     class Actual360 : public DayCounter {
       private:
         class Impl : public DayCounter::Impl {
+          private:
+              bool includeLastDay_;
           public:
-            std::string name() const { return std::string("Actual/360"); }
+            explicit Impl(const bool includeLastDay)
+            : includeLastDay_(includeLastDay) {}
+            std::string name() const {
+                return includeLastDay_ ?
+                    std::string("Actual/360 (inc)")
+                    : std::string("Actual/360");
+            }
+            Date::serial_type dayCount(const Date& d1,
+                                       const Date& d2) const {
+                return (d2-d1) + (includeLastDay_ ? 1 : 0);
+            }
             Time yearFraction(const Date& d1,
                               const Date& d2,
                               const Date&,
                               const Date&) const {
-                return daysBetween(d1,d2)/360.0;
+                return (daysBetween(d1,d2)
+                        + (includeLastDay_ ? 1.0 : 0.0))/360.0;
             }
         };
       public:
-        Actual360()
+        explicit Actual360(const bool includeLastDay = false)
         : DayCounter(boost::shared_ptr<DayCounter::Impl>(
-                                                      new Actual360::Impl)) {}
+            new Actual360::Impl(includeLastDay))) {}
     };
 
 }
