@@ -22,11 +22,12 @@
 namespace QuantLib {
 
     boost::shared_ptr<DayCounter::Impl>
-    ActualActual::implementation(ActualActual::Convention c) {
+    ActualActual::implementation(ActualActual::Convention c, 
+                                 const Schedule& schedule) {
         switch (c) {
           case ISMA:
           case Bond:
-            return boost::shared_ptr<DayCounter::Impl>(new ISMA_Impl);
+            return boost::shared_ptr<DayCounter::Impl>(new ISMA_Impl(schedule));
           case ISDA:
           case Historical:
           case Actual365:
@@ -96,7 +97,16 @@ namespace QuantLib {
                 // this case is long first coupon
 
                 // the last notional payment date
-                Date previousRef = refPeriodStart - months*Months;
+                Date previousRef;
+                if (schedule_.empty()) {
+                    previousRef = refPeriodStart - months*Months;
+                } else {
+                    previousRef = schedule_.calendar().advance(refPeriodStart,
+                                                               -schedule_.tenor(),
+                                                               schedule_.businessDayConvention(),
+                                                               schedule_.endOfMonth());
+                }
+
                 if (d2 > refPeriodStart)
                     return yearFraction(d1, refPeriodStart, previousRef,
                                         refPeriodStart) +
