@@ -48,8 +48,8 @@ namespace QuantLib {
         class Impl : public DayCounter::Impl {
           public:
             std::string name() const { return "Simple"; }
-            BigInteger dayCount(const Date& d1,
-                                const Date& d2) const;
+            Date::serial_type dayCount(const Date& d1,
+                                       const Date& d2) const;
             Time yearFraction(const Date& d1,
                               const Date& d2,
                               const Date&,
