@@ -23,7 +23,14 @@
 #include <ql/time/imm.hpp>
 #include <ql/settings.hpp>
 #include <ql/utilities/dataparsers.hpp>
+#if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)) || (__GNUC__ > 4))
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wunused-local-typedefs"
+#endif
 #include <boost/algorithm/string/case_conv.hpp>
+#if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)) || (__GNUC__ > 4))
+#pragma GCC diagnostic pop
+#endif
 
 using boost::algorithm::to_upper_copy;
 using std::string;
