@@ -28,11 +28,13 @@
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-local-typedefs"
 #endif
-#ifndef x64
+#if !defined(x64) && !defined(QL_PATCH_SOLARIS)
 #include <boost/lexical_cast.hpp>
 #endif
+#ifndef QL_PATCH_SOLARIS
 #include <boost/algorithm/string/case_conv.hpp>
 #include <boost/date_time/gregorian/gregorian.hpp>
+#endif
 #if defined(__GNUC__) && (((__GNUC__ == 4) && (__GNUC_MINOR__ >= 8)) || (__GNUC__ > 4))
 #pragma GCC diagnostic pop
 #endif
@@ -47,8 +49,8 @@ namespace QuantLib {
     namespace io {
 
         Integer to_integer(const std::string& str) {
-        #ifndef x64
-            return  boost::lexical_cast<Integer>(str.c_str());
+        #if !defined(x64) && !defined(QL_PATCH_SOLARIS)
+            return boost::lexical_cast<Integer>(str.c_str());
         #else
             return std::atoi(str.c_str());
         #endif
@@ -98,7 +100,6 @@ namespace QuantLib {
         Integer n;
         try {
             n = io::to_integer(str.substr(nPos,iPos));
-                //boost::lexical_cast<Integer>(str.substr(nPos,iPos));
         } catch (std::exception& e) {
             QL_FAIL("unable to parse the number of units of " << units <<
                     " in '" << str << "'. Error:" << e.what());
@@ -109,6 +110,7 @@ namespace QuantLib {
 
     Date DateParser::parseFormatted(const std::string& str,
                                     const std::string& fmt) {
+        #ifndef QL_PATCH_SOLARIS
         using namespace boost::gregorian;
 
         date boostDate;
@@ -118,18 +120,17 @@ namespace QuantLib {
         is >> boostDate;
         date_duration noDays = boostDate - date(1901, 1, 1);
         return Date(1, January, 1901) + noDays.days();
+        #else
+        QL_FAIL("DateParser::parseFormatted not supported under Solaris");
+        #endif
     }
 
     Date DateParser::parseISO(const std::string& str) {
         QL_REQUIRE(str.size() == 10 && str[4] == '-' && str[7] == '-',
                    "invalid format");
-        Integer year = //boost::lexical_cast<Integer>(str.substr(0, 4));
-            io::to_integer(str.substr(0, 4));
-        Month month =
-            //  static_cast<Month>(boost::lexical_cast<Integer>(str.substr(5, 2)));
-            static_cast<Month>(io::to_integer(str.substr(5, 2)));
-        Integer day = //boost::lexical_cast<Integer>(str.substr(8, 2));
-            static_cast<Month>(io::to_integer(str.substr(8, 2)));
+        Integer year = io::to_integer(str.substr(0, 4));
+        Month month = static_cast<Month>(io::to_integer(str.substr(5, 2)));
+        Integer day = io::to_integer(str.substr(8, 2));
 
         return Date(day, month, year);
     }
