@@ -1078,7 +1078,7 @@ void BasketOptionTest::test2DPDEGreeks() {
     const Real tol = 0.0005;
     if (std::fabs(expectedDelta - calculatedDelta) > tol) {
         BOOST_FAIL("failed to reproduce delta with 2dim PDE"
-                   << QL_FIXED << std::setprecision(8)
+                   << std::fixed << std::setprecision(8)
                    << "\n    calculated: " << calculatedDelta
                    << "\n    expected:   " << expectedDelta
                    << "\n    tolerance:  " << tol);
@@ -1086,33 +1086,38 @@ void BasketOptionTest::test2DPDEGreeks() {
 
     if (std::fabs(expectedGamma - calculatedGamma) > tol) {
         BOOST_FAIL("failed to reproduce delta with 2dim PDE"
-                   << QL_FIXED << std::setprecision(8)
+                   << std::fixed << std::setprecision(8)
                    << "\n    calculated: " << calculatedGamma
                    << "\n    expected:   " << expectedGamma
                    << "\n    tolerance:  " << tol);
     }
 }
 
-test_suite* BasketOptionTest::suite() {
+test_suite* BasketOptionTest::suite(SpeedLevel speed) {
     test_suite* suite = BOOST_TEST_SUITE("Basket option tests");
 
     suite->add(QUANTLIB_TEST_CASE(&BasketOptionTest::testEuroTwoValues));
-    // FLOATING_POINT_EXCEPTION
-    suite->add(QUANTLIB_TEST_CASE(
-                               &BasketOptionTest::testBarraquandThreeValues));
     suite->add(QUANTLIB_TEST_CASE(&BasketOptionTest::testTavellaValues));
 
-    const Size nTestCases = std::min(Size(5), LENGTH(oneDataValues));
-    for (Size i=0; i < nTestCases; ++i) {
-        suite->add(QUANTLIB_TEST_CASE(
-            boost::bind(&BasketOptionTest::testOneDAmericanValues,
-                (i    *LENGTH(oneDataValues))/nTestCases,
-                ((i+1)*LENGTH(oneDataValues))/nTestCases)));
-    }
     suite->add(QUANTLIB_TEST_CASE(&BasketOptionTest::testOddSamples));
     suite->add(QUANTLIB_TEST_CASE(
         &BasketOptionTest::testLocalVolatilitySpreadOption));
     suite->add(QUANTLIB_TEST_CASE(&BasketOptionTest::test2DPDEGreeks));
 
+    if (speed <= Fast) {
+        const Size nTestCases = std::min(Size(5), LENGTH(oneDataValues));
+        for (Size i=0; i < nTestCases; ++i) {
+            suite->add(QUANTLIB_TEST_CASE(
+                boost::bind(&BasketOptionTest::testOneDAmericanValues,
+                    (i    *LENGTH(oneDataValues))/nTestCases,
+                    ((i+1)*LENGTH(oneDataValues))/nTestCases)));
+        }
+    }
+
+    if (speed == Slow) {
+        suite->add(QUANTLIB_TEST_CASE(
+            &BasketOptionTest::testBarraquandThreeValues));
+    }
+
     return suite;
 }
