@@ -298,10 +298,16 @@ void BermudanSwaptionTest::testCachedG2Values() {
     }
 }
 
-test_suite* BermudanSwaptionTest::suite() {
+test_suite* BermudanSwaptionTest::suite(SpeedLevel speed) {
     test_suite* suite = BOOST_TEST_SUITE("Bermudan swaption tests");
+
     suite->add(QUANTLIB_TEST_CASE(&BermudanSwaptionTest::testCachedValues));
-    suite->add(QUANTLIB_TEST_CASE(&BermudanSwaptionTest::testCachedG2Values));
+
+    if (speed == Slow) {
+        suite->add(QUANTLIB_TEST_CASE(
+            &BermudanSwaptionTest::testCachedG2Values));
+    }
+
     return suite;
 }
 
