@@ -433,18 +433,22 @@ void DateTest::intraday() {
 }
 
 
-test_suite* DateTest::suite() {
+test_suite* DateTest::suite(SpeedLevel speed) {
     test_suite* suite = BOOST_TEST_SUITE("Date tests");
+
     suite->add(QUANTLIB_TEST_CASE(&DateTest::testConsistency));
     suite->add(QUANTLIB_TEST_CASE(&DateTest::ecbDates));
     suite->add(QUANTLIB_TEST_CASE(&DateTest::immDates));
-    suite->add(QUANTLIB_TEST_CASE(&DateTest::asxDates));
     suite->add(QUANTLIB_TEST_CASE(&DateTest::isoDates));
     #ifndef QL_PATCH_SOLARIS
     suite->add(QUANTLIB_TEST_CASE(&DateTest::parseDates));
     #endif
     suite->add(QUANTLIB_TEST_CASE(&DateTest::intraday));
 
+    if (speed <= Fast) {
+        suite->add(QUANTLIB_TEST_CASE(&DateTest::asxDates));
+    }
+
     return suite;
 }
 
