@@ -30,7 +30,7 @@ using namespace boost::unit_test_framework;
 
 void EverestOptionTest::testCached() {
 
-    BOOST_MESSAGE("Testing Everest option against cached values...");
+    BOOST_TEST_MESSAGE("Testing Everest option against cached values...");
 
     Date today = Settings::instance().evaluationDate();
 
@@ -121,7 +121,7 @@ void EverestOptionTest::testCached() {
                             .withAbsoluteTolerance(tolerance)
                             .withSeed(seed));
 
-    value = option.NPV();
+    option.NPV();
     Real accuracy = option.errorEstimate();
     if (accuracy > tolerance)
         BOOST_FAIL(std::setprecision(10)
