@@ -99,6 +99,7 @@ namespace {
                 new BinomialVanillaEngine<ExtendedCoxRossRubinstein>(
                                                               stochProcess,
                                                               binomialSteps));
+            break;
           case EQP:
             engine = boost::shared_ptr<PricingEngine>(
                 new BinomialVanillaEngine<ExtendedAdditiveEQPBinomialTree>(
@@ -136,29 +137,6 @@ namespace {
         return option;
     }
 
-    std::string engineTypeToString(EngineType type) {
-        switch (type) {
-          case Analytic:
-            return "analytic";
-          case JR:
-            return "Jarrow-Rudd";
-          case CRR:
-            return "Cox-Ross-Rubinstein";
-          case EQP:
-            return "EQP";
-          case TGEO:
-            return "Trigeorgis";
-          case TIAN:
-            return "Tian";
-          case LR:
-            return "LeisenReimer";
-          case JOSHI:
-            return "Joshi";
-          default:
-            QL_FAIL("unknown engine type");
-        }
-    }
-
 }
 
 namespace {
@@ -266,8 +244,8 @@ namespace {
 
 void ExtendedTreesTest::testJRBinomialEngines() {
 
-    BOOST_MESSAGE("Testing time-dependent JR binomial European engines "
-                  "against analytic results...");
+    BOOST_TEST_MESSAGE("Testing time-dependent JR binomial European engines "
+                       "against analytic results...");
 
     SavedSettings backup;
 
@@ -283,8 +261,8 @@ void ExtendedTreesTest::testJRBinomialEngines() {
 
 void ExtendedTreesTest::testCRRBinomialEngines() {
 
-    BOOST_MESSAGE("Testing time-dependent CRR binomial European engines "
-                  "against analytic results...");
+    BOOST_TEST_MESSAGE("Testing time-dependent CRR binomial European engines "
+                       "against analytic results...");
 
     SavedSettings backup;
 
@@ -300,8 +278,8 @@ void ExtendedTreesTest::testCRRBinomialEngines() {
 
 void ExtendedTreesTest::testEQPBinomialEngines() {
 
-    BOOST_MESSAGE("Testing time-dependent EQP binomial European engines "
-                  "against analytic results...");
+    BOOST_TEST_MESSAGE("Testing time-dependent EQP binomial European engines "
+                       "against analytic results...");
 
     SavedSettings backup;
 
@@ -317,8 +295,8 @@ void ExtendedTreesTest::testEQPBinomialEngines() {
 
 void ExtendedTreesTest::testTGEOBinomialEngines() {
 
-    BOOST_MESSAGE("Testing time-dependent TGEO binomial European engines "
-                  "against analytic results...");
+    BOOST_TEST_MESSAGE("Testing time-dependent TGEO binomial European engines "
+                       "against analytic results...");
 
     SavedSettings backup;
 
@@ -334,8 +312,8 @@ void ExtendedTreesTest::testTGEOBinomialEngines() {
 
 void ExtendedTreesTest::testTIANBinomialEngines() {
 
-    BOOST_MESSAGE("Testing time-dependent TIAN binomial European engines "
-                  "against analytic results...");
+    BOOST_TEST_MESSAGE("Testing time-dependent TIAN binomial European engines "
+                       "against analytic results...");
 
     SavedSettings backup;
 
@@ -351,8 +329,8 @@ void ExtendedTreesTest::testTIANBinomialEngines() {
 
 void ExtendedTreesTest::testLRBinomialEngines() {
 
-    BOOST_MESSAGE("Testing time-dependent LR binomial European engines "
-                  "against analytic results...");
+    BOOST_TEST_MESSAGE("Testing time-dependent LR binomial European engines "
+                       "against analytic results...");
 
     SavedSettings backup;
 
@@ -368,8 +346,8 @@ void ExtendedTreesTest::testLRBinomialEngines() {
 
 void ExtendedTreesTest::testJOSHIBinomialEngines() {
 
-    BOOST_MESSAGE("Testing time-dependent Joshi binomial European engines "
-                  "against analytic results...");
+    BOOST_TEST_MESSAGE("Testing time-dependent Joshi binomial European engines "
+                       "against analytic results...");
 
     SavedSettings backup;
 
