@@ -46,7 +46,7 @@ void FastFourierTransformTest::testSimple() {
         if ((std::fabs(b[i].real() - expected[i].real()) > 1.0e-2) ||
             (std::fabs(b[i].imag() - expected[i].imag()) > 1.0e-2))
             BOOST_ERROR("Convolution(" << i << ")\n"
-                        << std::setprecision(4) << QL_SCIENTIFIC
+                        << std::setprecision(4) << std::scientific
                         << "    calculated: " << b[i] << "\n"
                         << "    expected:   " << expected[i]);
     }
@@ -78,7 +78,7 @@ void FastFourierTransformTest::testInverse() {
     Real expected = x[0]*x[0] + x[1]*x[1] + x[2]*x[2];
     if (fabs (calculated - expected) > 1.0e-10)
         BOOST_ERROR("Convolution(0)\n"
-                    << std::setprecision(16) << QL_SCIENTIFIC
+                    << std::setprecision(16) << std::scientific
                     << "    calculated: " << calculated << "\n"
                     << "    expected:   " << expected);
 
@@ -87,7 +87,7 @@ void FastFourierTransformTest::testInverse() {
     expected = x[0]*x[1] + x[1]*x[2];
     if (fabs (calculated - expected) > 1.0e-10)
         BOOST_ERROR("Convolution(1)\n"
-                    << std::setprecision(16) << QL_SCIENTIFIC
+                    << std::setprecision(16) << std::scientific
                     << "    calculated: " << calculated << "\n"
                     << "    expected:   " << expected);
 
@@ -96,7 +96,7 @@ void FastFourierTransformTest::testInverse() {
     expected = x[0]*x[2];
     if (fabs (calculated - expected) > 1.0e-10)
         BOOST_ERROR("Convolution(1)\n"
-                    << std::setprecision(16) << QL_SCIENTIFIC
+                    << std::setprecision(16) << std::scientific
                     << "    calculated: " << calculated << "\n"
                     << "    expected:   " << expected);
 
