@@ -1501,24 +1501,19 @@ void HybridHestonHullWhiteProcessTest::testH1HWPricingEngine() {
     }
 }
     
-test_suite* HybridHestonHullWhiteProcessTest::suite() {
+test_suite* HybridHestonHullWhiteProcessTest::suite(SpeedLevel speed) {
     test_suite* suite = BOOST_TEST_SUITE("Hybrid Heston-HullWhite tests");
 
-    // FLOATING_POINT_EXCEPTION
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testBsmHullWhiteEngine));
-    // FLOATING_POINT_EXCEPTION
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testCompareBsmHWandHestonHW));
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testZeroBondPricing));
-    // FLOATING_POINT_EXCEPTION
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testMcVanillaPricing));
-    // FLOATING_POINT_EXCEPTION
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testMcPureHestonPricing));
-    // FLOATING_POINT_EXCEPTION
     suite->add(QUANTLIB_TEST_CASE(
       &HybridHestonHullWhiteProcessTest::testAnalyticHestonHullWhitePricing));
     suite->add(QUANTLIB_TEST_CASE(
@@ -1527,15 +1522,21 @@ test_suite* HybridHestonHullWhiteProcessTest::suite() {
         &HybridHestonHullWhiteProcessTest::testDiscretizationError));
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testFdmHestonHullWhiteEngine));
-    suite->add(QUANTLIB_TEST_CASE(
-        &HybridHestonHullWhiteProcessTest::testHestonHullWhiteCalibration));
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testBsmHullWhitePricing));
-    suite->add(QUANTLIB_TEST_CASE(
-        &HybridHestonHullWhiteProcessTest::testSpatialDiscretizatinError));
     suite->add(QUANTLIB_TEST_CASE(
         &HybridHestonHullWhiteProcessTest::testH1HWPricingEngine));
 
+    if (speed <= Fast) {
+        suite->add(QUANTLIB_TEST_CASE(
+            &HybridHestonHullWhiteProcessTest::testSpatialDiscretizatinError));
+    }
+
+    if (speed == Slow) {
+        suite->add(QUANTLIB_TEST_CASE(
+            &HybridHestonHullWhiteProcessTest::testHestonHullWhiteCalibration));
+    }
+
     return suite;
 }
 
