@@ -6,6 +6,7 @@
  Copyright (C) 2007 Giorgio Facchinetti
  Copyright (C) 2009 Dimitri Reiswich
  Copyright (C) 2014 Peter Caspers
+ Copyright (C) 2018 Klaus Spanderen
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -36,6 +37,7 @@
 #include <ql/math/interpolations/kernelinterpolation2d.hpp>
 #include <ql/math/interpolations/lagrangeinterpolation.hpp>
 #include <ql/math/integrals/simpsonintegral.hpp>
+#include <ql/math/bspline.hpp>
 #include <ql/math/kernelfunctions.hpp>
 #include <ql/math/functional.hpp>
 #include <ql/math/richardsonextrapolation.hpp>
@@ -43,6 +45,7 @@
 #include <ql/math/optimization/levenbergmarquardt.hpp>
 #include <ql/experimental/volatility/noarbsabrinterpolation.hpp>
 #include <boost/foreach.hpp>
+#include <boost/tuple/tuple.hpp>
 #include <boost/assign/std/vector.hpp>
 #include <boost/math/special_functions/fpclassify.hpp>
 
@@ -86,7 +89,7 @@ namespace {
             Real interpolated = cubic(*xBegin);
             if (std::fabs(interpolated-*yBegin) > tolerance) {
                 BOOST_ERROR(type << " interpolation failed at x = " << *xBegin
-                            << QL_SCIENTIFIC
+                            << std::scientific
                             << "\n    interpolated value: " << interpolated
                             << "\n    expected value:     " << *yBegin
                             << "\n    error:              "
@@ -108,7 +111,7 @@ namespace {
                         << "at x = " << x
                         << "\n    interpolated value: " << interpolated
                         << "\n    expected value:     " << value
-                        << QL_SCIENTIFIC
+                        << std::scientific
                         << "\n    error:              " << error);
         }
     }
@@ -125,7 +128,7 @@ namespace {
                         << "at x = " << x
                         << "\n    interpolated value: " << interpolated
                         << "\n    expected value:     " << value
-                        << QL_SCIENTIFIC
+                        << std::scientific
                         << "\n    error:              " << error);
         }
     }
@@ -932,15 +935,61 @@ void InterpolationTest::testAsFunctor() {
         if (std::fabs(y2[i]-expected) > tolerance)
             BOOST_ERROR(
                 "failed to reproduce " << io::ordinal(i+1) << " expected datum"
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << y2[i]
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(y2[i]-expected));
     }
 }
 
 
+namespace {
+
+    Integer sign(Real y1, Real y2) {
+        return y1 == y2 ? 0 :
+               y1 < y2 ?  1 :
+                         -1 ;
+    }
+
+}
+
+void InterpolationTest::testFritschButland() {
+
+    BOOST_TEST_MESSAGE("Testing Fritsch-Butland interpolation...");
+
+    const Real x[5] = { 0.0, 1.0, 2.0, 3.0, 4.0 };
+    const Real y[][5] = {{ 1.0, 2.0, 1.0, 1.0, 2.0 },
+                         { 1.0, 2.0, 1.0, 1.0, 1.0 },
+                         { 2.0, 1.0, 0.0, 2.0, 3.0 }};
+
+    for (Size i=0; i<3; ++i) {
+
+        Interpolation f = FritschButlandCubic(BEGIN(x), END(x), BEGIN(y[i]));
+        f.update();
+
+        for (Size j=0; j<4; ++j) {
+            Real left_knot = x[j];
+            Integer expected_sign = sign(y[i][j], y[i][j+1]);
+            for (Size k=0; k<10; ++k) {
+                Real x1 = left_knot + k*0.1, x2 = left_knot + (k+1)*0.1;
+                Real y1 = f(x1), y2 = f(x2);
+                if (boost::math::isnan(y1))
+                    BOOST_ERROR("NaN detected in case " << i << ":"
+                                << std::fixed
+                                << "\n    f(" << x1 << ") = " << y1);
+                else if (sign(y1, y2) != expected_sign)
+                    BOOST_ERROR("interpolation is not monotonic "
+                                "in case " << i << ":"
+                                << std::fixed
+                                << "\n    f(" << x1 << ") = " << y1
+                                << "\n    f(" << x2 << ") = " << y2);
+            }
+        }
+    }
+}
+
+
 void InterpolationTest::testBackwardFlat() {
 
     BOOST_TEST_MESSAGE("Testing backward-flat interpolation...");
@@ -963,10 +1012,10 @@ void InterpolationTest::testBackwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to reproduce " << io::ordinal(i+1) << " datum"
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 
@@ -978,10 +1027,10 @@ void InterpolationTest::testBackwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to interpolate correctly at " << p
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 
@@ -994,10 +1043,10 @@ void InterpolationTest::testBackwardFlat() {
     if (std::fabs(expected-calculated) > tolerance)
         BOOST_ERROR(
             "failed to extrapolate correctly at " << p
-            << QL_FIXED
+            << std::fixed
             << "\n    expected:   " << expected
             << "\n    calculated: " << calculated
-            << QL_SCIENTIFIC
+            << std::scientific
             << "\n    error:      " << std::fabs(calculated-expected));
 
     p = x[N-1] + 0.5;
@@ -1006,10 +1055,10 @@ void InterpolationTest::testBackwardFlat() {
     if (std::fabs(expected-calculated) > tolerance)
         BOOST_ERROR(
             "failed to extrapolate correctly at " << p
-            << QL_FIXED
+            << std::fixed
             << "\n    expected:   " << expected
             << "\n    calculated: " << calculated
-            << QL_SCIENTIFIC
+            << std::scientific
             << "\n    error:      " << std::fabs(calculated-expected));
 
     // primitive at original points
@@ -1018,10 +1067,10 @@ void InterpolationTest::testBackwardFlat() {
     if (std::fabs(expected-calculated) > tolerance)
         BOOST_ERROR(
             "failed to calculate primitive at " << x[0]
-            << QL_FIXED
+            << std::fixed
             << "\n    expected:   " << expected
             << "\n    calculated: " << calculated
-            << QL_SCIENTIFIC
+            << std::scientific
             << "\n    error:      " << std::fabs(calculated-expected));
 
     Real sum = 0.0;
@@ -1032,10 +1081,10 @@ void InterpolationTest::testBackwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to calculate primitive at " << x[i]
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 
@@ -1050,10 +1099,10 @@ void InterpolationTest::testBackwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to calculate primitive at " << x[i]
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 
@@ -1081,10 +1130,10 @@ void InterpolationTest::testForwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to reproduce " << io::ordinal(i+1) << " datum"
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 
@@ -1096,10 +1145,10 @@ void InterpolationTest::testForwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to interpolate correctly at " << p
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 
@@ -1112,10 +1161,10 @@ void InterpolationTest::testForwardFlat() {
     if (std::fabs(expected-calculated) > tolerance)
         BOOST_ERROR(
             "failed to extrapolate correctly at " << p
-            << QL_FIXED
+            << std::fixed
             << "\n    expected:   " << expected
             << "\n    calculated: " << calculated
-            << QL_SCIENTIFIC
+            << std::scientific
             << "\n    error:      " << std::fabs(calculated-expected));
 
     p = x[N-1] + 0.5;
@@ -1124,10 +1173,10 @@ void InterpolationTest::testForwardFlat() {
     if (std::fabs(expected-calculated) > tolerance)
         BOOST_ERROR(
             "failed to extrapolate correctly at " << p
-            << QL_FIXED
+            << std::fixed
             << "\n    expected:   " << expected
             << "\n    calculated: " << calculated
-            << QL_SCIENTIFIC
+            << std::scientific
             << "\n    error:      " << std::fabs(calculated-expected));
 
     // primitive at original points
@@ -1136,10 +1185,10 @@ void InterpolationTest::testForwardFlat() {
     if (std::fabs(expected-calculated) > tolerance)
         BOOST_ERROR(
             "failed to calculate primitive at " << x[0]
-            << QL_FIXED
+            << std::fixed
             << "\n    expected:   " << expected
             << "\n    calculated: " << calculated
-            << QL_SCIENTIFIC
+            << std::scientific
             << "\n    error:      " << std::fabs(calculated-expected));
 
     Real sum = 0.0;
@@ -1150,10 +1199,10 @@ void InterpolationTest::testForwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to calculate primitive at " << x[i]
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 
@@ -1168,10 +1217,10 @@ void InterpolationTest::testForwardFlat() {
         if (std::fabs(expected-calculated) > tolerance)
             BOOST_ERROR(
                 "failed to calculate primitive at " << p
-                << QL_FIXED
+                << std::fixed
                 << "\n    expected:   " << expected
                 << "\n    calculated: " << calculated
-                << QL_SCIENTIFIC
+                << std::scientific
                 << "\n    error:      " << std::fabs(calculated-expected));
     }
 }
@@ -1393,7 +1442,7 @@ void InterpolationTest::testKernelInterpolation() {
 
                     BOOST_ERROR("Kernel interpolation failed at x = "
                                 << deltaGrid[dIt]
-                                << QL_SCIENTIFIC
+                                << std::scientific
                                 << "\n    interpolated value: " << calcVal
                                 << "\n    expected value:     " << expectedVal
                                 << "\n    error:              "
@@ -1450,7 +1499,7 @@ void InterpolationTest::testKernelInterpolation() {
 
                 BOOST_ERROR("Kernel interpolation failed at x = "
                             << deltaGrid[dIt]
-                            << QL_SCIENTIFIC
+                            << std::scientific
                             << "\n    interpolated value: " << calcVal
                             << "\n    expected value:     " << expectedVal
                             << "\n    error:              "
@@ -2152,6 +2201,89 @@ void InterpolationTest::testLagrangeInterpolationOnChebyshevPoints() {
     }
 }
 
+void InterpolationTest::testBSplines() {
+    BOOST_TEST_MESSAGE("Testing B-Splines...");
+
+    // reference values have been generate with the R package splines2
+    // https://cran.r-project.org/web/packages/splines2/splines2.pdf
+
+    using namespace boost::assign;
+
+    std::vector<Real> knots;
+    knots += -1.0, 0.5, 0.75, 1.2, 3.0, 4.0, 5.0;
+
+    const Natural p = 2;
+    const BSpline bspline(p, knots.size()-p-2, knots);
+
+    std::vector<boost::tuple<Natural, Real, Real> > referenceValues;
+    referenceValues += boost::make_tuple(0, -0.95, 9.5238095238e-04),
+        boost::make_tuple(0, -0.01, 0.37337142857),
+        boost::make_tuple(0, 0.49, 0.84575238095),
+        boost::make_tuple(0, 1.21, 0.0),
+        boost::make_tuple(1, 1.49, 0.562987654321),
+        boost::make_tuple(1, 1.59, 0.490888888889),
+        boost::make_tuple(2, 1.99, 0.62429409171),
+        boost::make_tuple(3, 1.19, 0.0),
+        boost::make_tuple(3, 1.99, 0.12382936508),
+        boost::make_tuple(3, 3.59, 0.765914285714);
+
+
+    const Real tol = 1e-10;
+    for (Size i=0; i < referenceValues.size(); ++i) {
+        const Natural idx = referenceValues[i].get<0>();
+        const Real x = referenceValues[i].get<1>();
+        const Real expected = referenceValues[i].get<2>();
+
+        const Real calculated = bspline(idx, x);
+
+        if (   boost::math::isnan(calculated)
+            || std::fabs(calculated - expected) > tol) {
+            BOOST_FAIL("failed to reproduce the B-Spline value"
+                    << "\n    i         : " << idx
+                    << "\n    x         : " << x
+                    << "\n    calculated: " << calculated
+                    << "\n    expected  : " << expected
+                    << "\n    difference: " << std::fabs(calculated-expected)
+                    << "\n    tolerance : " << tol);
+        }
+    }
+}
+
+
+void InterpolationTest::testBackwardFlatOnSinglePoint() {
+    BOOST_TEST_MESSAGE("Testing piecewise constant interpolation on a "
+                       "single point...");
+    const std::vector<Real> knots(1, 1.0), values(1, 2.5);
+
+    const Interpolation impl(BackwardFlat().interpolate(
+        knots.begin(), knots.end(), values.begin()));
+
+    const Real x[] = { -1.0, 1.0, 2.0, 3.0 };
+
+    for (Size i=0; i < LENGTH(x); ++i) {
+        const Real calculated = impl(x[i], true);
+        const Real expected = values[0];
+
+        if (!close_enough(calculated, expected)) {
+            BOOST_FAIL("failed to reproduce a piecewise constant "
+                    "interpolation on a single point "
+                    << "\n   x         : " << x[i]
+                    << "\n   expected  : " << expected
+                    << "\n   calculated: " << calculated);
+        }
+
+        const Real expectedPrimitive = values[0]*(x[i] - knots[0]);
+        const Real calculatedPrimitive = impl.primitive(x[i], true);
+
+        if (!close_enough(calculatedPrimitive, expectedPrimitive)) {
+            BOOST_FAIL("failed to reproduce primitive on a piecewise constant "
+                    "interpolation for a single point "
+                    << "\n   x         : " << x[i]
+                    << "\n   expected  : " << expectedPrimitive
+                    << "\n   calculated: " << calculatedPrimitive);
+        }
+    }
+}
 
 test_suite* InterpolationTest::suite() {
     test_suite* suite = BOOST_TEST_SUITE("Interpolation tests");
@@ -2172,6 +2304,7 @@ test_suite* InterpolationTest::suite() {
                         &InterpolationTest::testSplineErrorOnGaussianValues));
     suite->add(QUANTLIB_TEST_CASE(&InterpolationTest::testMultiSpline));
     suite->add(QUANTLIB_TEST_CASE(&InterpolationTest::testAsFunctor));
+    suite->add(QUANTLIB_TEST_CASE(&InterpolationTest::testFritschButland));
     suite->add(QUANTLIB_TEST_CASE(&InterpolationTest::testBackwardFlat));
     suite->add(QUANTLIB_TEST_CASE(&InterpolationTest::testForwardFlat));
     suite->add(QUANTLIB_TEST_CASE(&InterpolationTest::testSabrInterpolation));
@@ -2191,9 +2324,12 @@ test_suite* InterpolationTest::suite() {
         &InterpolationTest::testLagrangeInterpolationAtSupportPoint));
     suite->add(QUANTLIB_TEST_CASE(
         &InterpolationTest::testLagrangeInterpolationDerivative));
-
     suite->add(QUANTLIB_TEST_CASE(
         &InterpolationTest::testLagrangeInterpolationOnChebyshevPoints));
+    suite->add(QUANTLIB_TEST_CASE(&InterpolationTest::testBSplines));
+
+    suite->add(QUANTLIB_TEST_CASE(
+        &InterpolationTest::testBackwardFlatOnSinglePoint));
 
     return suite;
 }
