@@ -332,15 +332,19 @@ void LiborMarketModelProcessTest::testMonteCarloCapletPricing() {
     }
 }
 
-test_suite* LiborMarketModelProcessTest::suite() {
+test_suite* LiborMarketModelProcessTest::suite(SpeedLevel speed) {
     test_suite* suite = BOOST_TEST_SUITE("Libor market model process tests");
 
     suite->add(QUANTLIB_TEST_CASE(
          &LiborMarketModelProcessTest::testInitialisation));
     suite->add(QUANTLIB_TEST_CASE(
          &LiborMarketModelProcessTest::testLambdaBootstrapping));
-    suite->add(QUANTLIB_TEST_CASE(
-          &LiborMarketModelProcessTest::testMonteCarloCapletPricing));
+
+    if (speed <= Fast) {
+        suite->add(QUANTLIB_TEST_CASE(
+            &LiborMarketModelProcessTest::testMonteCarloCapletPricing));
+    }
+
     return suite;
 }
 
