@@ -531,11 +531,13 @@ void MarketModelCmsTest::testMultiStepCmSwapsAndSwaptions() {
 
 
 // --- Call the desired tests
-test_suite* MarketModelCmsTest::suite() {
+test_suite* MarketModelCmsTest::suite(SpeedLevel speed) {
     test_suite* suite = BOOST_TEST_SUITE("CMS Market-model tests");
 
-    suite->add(QUANTLIB_TEST_CASE(
+    if (speed == Slow) {
+        suite->add(QUANTLIB_TEST_CASE(
                       &MarketModelCmsTest::testMultiStepCmSwapsAndSwaptions));
+    }
 
     return suite;
 }
