@@ -258,7 +258,7 @@ void MarketModelSmmCapletAlphaCalibrationTest::testFunction() {
     std::vector<Real> alphaMin(numberOfRates, -1.0);
     bool maximizeHomogeneity = false; //?
     if (printReport_) {
-        BOOST_TEST_MESSAGE("caplet market vols: " << QL_FIXED <<
+        BOOST_TEST_MESSAGE("caplet market vols: " << std::fixed <<
                            std::setprecision(4) << io::sequence(capletVols_));
         BOOST_TEST_MESSAGE("alphaMin:           " << alphaMin_);
         BOOST_TEST_MESSAGE("alphaInitial:       " << alpha_);
@@ -311,7 +311,7 @@ void MarketModelSmmCapletAlphaCalibrationTest::testFunction() {
         capletVols[i] = std::sqrt(capletTotCovariance[i][i]/rateTimes_[i]);
     }
     if (printReport_) {
-        BOOST_TEST_MESSAGE("caplet smm implied vols: " << QL_FIXED <<
+        BOOST_TEST_MESSAGE("caplet smm implied vols: " << std::fixed <<
                            std::setprecision(4) << io::sequence(capletVols));
         BOOST_TEST_MESSAGE("failures: " << calibrator.failures());
         BOOST_TEST_MESSAGE("deformationSize: " << calibrator.deformationSize());
