@@ -268,7 +268,7 @@ void MarketModelSmmCapletHomoCalibrationTest::testFunction() {
     // create calibrator
     Real caplet0Swaption1Priority = 1.0;
     if (printReport_) {
-        BOOST_TEST_MESSAGE("caplet market vols: " << QL_FIXED <<
+        BOOST_TEST_MESSAGE("caplet market vols: " << std::fixed <<
                            std::setprecision(4) << io::sequence(capletVols_));
         BOOST_TEST_MESSAGE("caplet0Swapt1Prior: " << caplet0Swaption1Priority);
     }
@@ -313,7 +313,7 @@ void MarketModelSmmCapletHomoCalibrationTest::testFunction() {
         capletVols[i] = std::sqrt(capletTotCovariance[i][i]/rateTimes_[i]);
     }
     if (printReport_) {
-        BOOST_TEST_MESSAGE("caplet smm implied vols: " << QL_FIXED <<
+        BOOST_TEST_MESSAGE("caplet smm implied vols: " << std::fixed <<
                            std::setprecision(4) << io::sequence(capletVols));
         BOOST_TEST_MESSAGE("failures: " << calibrator.failures());
         BOOST_TEST_MESSAGE("deformationSize: " << calibrator.deformationSize());
@@ -357,7 +357,7 @@ void MarketModelSmmCapletHomoCalibrationTest::testFunction() {
     boost::shared_ptr<MarketModel> adapted(new FwdPeriodAdapter(flmm,period,offset,adaptedDisplacements));
    // FwdToCotSwapAdapter newSwapMM(adapted);
    // for (Size i=0; i < newSwapMM.numberOfRates(); ++i)
-     //      BOOST_TEST_MESSAGE("swap MM time dependent vols: "<< i << QL_FIXED <<
+     //      BOOST_TEST_MESSAGE("swap MM time dependent vols: "<< i << std::fixed <<
        //               std::setprecision(6) << Array(newSwapMM.timeDependentVolatility(i)));
 
 
@@ -416,7 +416,7 @@ void MarketModelSmmCapletHomoCalibrationTest::testPeriodFunction()
     // create calibrator
     Real caplet0Swaption1Priority = 1.0;
     if (printReport_) {
-        BOOST_TEST_MESSAGE("caplet market vols: " << QL_FIXED <<
+        BOOST_TEST_MESSAGE("caplet market vols: " << std::fixed <<
                            std::setprecision(4) << io::sequence(capletVols_));
         BOOST_TEST_MESSAGE("caplet0Swapt1Prior: " << caplet0Swaption1Priority);
     }
