@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2008 Ferdinando Ametrano
  Copyright (C) 2007, 2008 Laurent Hoffmann
+ Copyright (C) 2015, 2016 Michael von den Driesch
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -30,8 +31,11 @@ class OptionletStripperTest {
   public:
     static void testFlatTermVolatilityStripping1();
     static void testTermVolatilityStripping1();
+    static void testTermVolatilityStrippingNormalVol();
+    static void testTermVolatilityStrippingShiftedLogNormalVol();
     static void testFlatTermVolatilityStripping2();
     static void testTermVolatilityStripping2();
+    static void testSwitchStrike();
     static boost::unit_test_framework::test_suite* suite();
 };
 
