@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2009 Roland Lichters
+ Copyright (C) 2014 Peter Caspers
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -31,6 +32,8 @@ class OvernightIndexedSwapTest {
     static void testFairSpread();
     static void testCachedValue();
     static void testBootstrap();
+    static void testBootstrapWithTelescopicDates();
+    static void testSeasonedSwaps();
     static boost::unit_test_framework::test_suite* suite();
 };
 
