@@ -21,6 +21,7 @@
 #define quantlib_test_short_rate_models_hpp
 
 #include <boost/test/unit_test.hpp>
+#include "speedlevel.hpp"
 
 /* remember to document new and/or updated tests in the Doxygen
    comment block of the corresponding class */
@@ -32,7 +33,7 @@ class ShortRateModelTest {
     static void testCachedHullWhiteFixedReversion();
     static void testCachedHullWhite2();
     static void testSwaps();
-    static boost::unit_test_framework::test_suite* suite();
+    static boost::unit_test_framework::test_suite* suite(SpeedLevel);
 };
 
 
