@@ -58,35 +58,40 @@ struct Case {
     Volatility sigma2;
     Real rho;
     Natural length;
-    Real result;
+    Real value;
+    Real theta;
 };
 
 void SpreadOptionTest::testKirkEngine() {
     BOOST_TEST_MESSAGE("Testing Kirk approximation for spread options...");
 
     /* The example data below are from "complete guide to option
-       pricing formulas", Espen Gaarder Haug, p 60 */
+       pricing formulas", Espen Gaarder Haug, p 60
+
+       Expected values of option theta were calculated using automatic
+       differentiation of the pricing function. The engine uses closed-form
+       formula */
 
     Case cases[] = {
-        {  28.0,  20.0, 7.0, 0.05, 0.29, 0.36,  0.42, 90,  2.1670 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20, -0.5,  36,  4.7530 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.0,  36,  3.7970 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.5,  36,  2.5537 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20, -0.5, 180, 10.7517 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.0, 180,  8.7020 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.5, 180,  6.0257 },
-        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20, -0.5,  36,  5.4275 },
-        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.0,  36,  4.3712 },
-        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.5,  36,  3.0086 },
-        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20, -0.5, 180, 12.1941 },
-        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.0, 180,  9.9340 },
-        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.5, 180,  7.0067 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25, -0.5,  36,  5.4061 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.0,  36,  4.3451 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.5,  36,  2.9723 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25, -0.5, 180, 12.1483 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.0, 180,  9.8780 },
-        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.5, 180,  6.9284 }
+        {  28.0,  20.0, 7.0, 0.05, 0.29, 0.36,  0.42, 90,  2.1670,  3.0431 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20, -0.5,  36,  4.7530, 25.5905 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.0,  36,  3.7970, 20.8841 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.5,  36,  2.5537, 14.7260 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20, -0.5, 180, 10.7517, 10.0847 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.0, 180,  8.7020,  8.2619 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.20,  0.5, 180,  6.0257,  5.8661 },
+        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20, -0.5,  36,  5.4275, 28.9013 },
+        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.0,  36,  4.3712, 23.7133 },
+        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.5,  36,  3.0086, 16.9864 },
+        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20, -0.5, 180, 12.1941, 11.3603 },
+        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.0, 180,  9.9340,  9.3589 },
+        { 122.0, 120.0, 3.0, 0.10, 0.25, 0.20,  0.5, 180,  7.0067,  6.7463 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25, -0.5,  36,  5.4061, 28.7963 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.0,  36,  4.3451, 23.5848 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.5,  36,  2.9723, 16.8060 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25, -0.5, 180, 12.1483, 11.3200 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.0, 180,  9.8780,  9.3091 },
+        { 122.0, 120.0, 3.0, 0.10, 0.20, 0.25,  0.5, 180,  6.9284,  6.6761 }
     };
 
     for (Size i=0; i<LENGTH(cases); ++i) {
@@ -146,14 +151,20 @@ void SpreadOptionTest::testKirkEngine() {
         option.setPricingEngine(engine);
 
         // And test the data
-        Real calculated = option.NPV();
-        Real expected = cases[i].result;
+        Real value = option.NPV();
+        Real theta = option.theta();
         Real tolerance = 1e-4;
 
-        if (std::fabs(calculated-expected) > tolerance) {
+        if (std::fabs(value-cases[i].value) > tolerance) {
             REPORT_FAILURE("value",
                            payoff, exercise,
-                           expected, calculated, tolerance);
+                           cases[i].value, value, tolerance);
+        }
+
+        if (std::fabs(theta-cases[i].theta) > tolerance) {
+            REPORT_FAILURE("theta",
+                            payoff, exercise,
+                            cases[i].theta, theta, tolerance);
         }
     }
 }
