@@ -100,7 +100,7 @@ namespace boost {
     template<>
     struct hash<Date> : std::unary_function<Date, std::size_t> {
         size_t operator()(const Date& _Keyval) const {
-            return boost::hash<BigInteger>()(_Keyval.serialNumber());
+            return boost::hash<Date::serial_type>()(_Keyval.serialNumber());
         }
     };
 
