@@ -22,7 +22,7 @@
 #include <ql/math/matrixutilities/tqreigendecomposition.hpp>
 
 using namespace QuantLib;
-using namespace boost::unit_test_framework;
+using boost::unit_test_framework::test_suite;
 
 namespace {
 
